Module: LanguageServer::Protocol::Constant::CodeActionTriggerKind

Defined in:
lib/language_server/protocol/constant/code_action_trigger_kind.rb

Overview

The reason why code actions were requested.

Since:

  • 3.17.0

Constant Summary collapse

INVOKED =

Code actions were explicitly requested by the user or by an extension.

Since:

  • 3.17.0

1
AUTOMATIC =

Code actions were requested automatically.

This typically happens when current selection in a file changes, but can also be triggered when file content changes.

Since:

  • 3.17.0

2