Module: LanguageServer::Protocol::Constant::CompletionItemTag

Defined in:
lib/language_server/protocol/constant/completion_item_tag.rb

Overview

Completion item tags are extra annotations that tweak the rendering of a completion item.

Since:

  • 3.15.0

Constant Summary collapse

DEPRECATED =

Render a completion as obsolete, usually using a strike-out.

Since:

  • 3.15.0

1