Module: LanguageServer::Protocol::Constant::DiagnosticTag

Defined in:
lib/language_server/protocol/constant/diagnostic_tag.rb,
sig/language_server/protocol/constant/diagnostic_tag.rbs

Overview

The diagnostic tags.

Constant Summary collapse

UNNECESSARY =

Unused or unnecessary code.

Clients are allowed to render diagnostics with this tag faded out instead of having an error squiggle.

Returns:

  • (1)
1
DEPRECATED =

Deprecated or obsolete code.

Clients are allowed to rendered diagnostics with this tag strike through.

Returns:

  • (2)
2