Module: LanguageServer::Protocol::Constant::DocumentDiagnosticReportKind

Defined in:
lib/language_server/protocol/constant/document_diagnostic_report_kind.rb,
sig/language_server/protocol/constant/document_diagnostic_report_kind.rbs

Overview

The document diagnostic report kinds.

Constant Summary collapse

FULL =

A diagnostic report with a full set of problems.

Returns:

  • ('full')
'full'
UNCHANGED =

A report indicating that the last returned report is still accurate.

Returns:

  • ('unchanged')
'unchanged'