Module: LanguageServer::Protocol::Constant::MonikerKind

Defined in:
lib/language_server/protocol/constant/moniker_kind.rb,
sig/language_server/protocol/constant/moniker_kind.rbs

Overview

The moniker kind.

Constant Summary collapse

IMPORT =

The moniker represent a symbol that is imported into a project

Returns:

  • ('import')
'import'
EXPORT =

The moniker represents a symbol that is exported from a project

Returns:

  • ('export')
'export'
LOCAL =

The moniker represents a symbol that is local to a project (e.g. a local variable of a function, a class not visible outside the project, ...)

Returns:

  • ('local')
'local'