Module: LanguageServer::Protocol::Constant::PositionEncodingKind

Defined in:
lib/language_server/protocol/constant/position_encoding_kind.rb,
sig/language_server/protocol/constant/position_encoding_kind.rbs

Overview

A type indicating how positions are encoded, specifically what column offsets mean. A set of predefined position encoding kinds.

Constant Summary collapse

UTF8 =

Character offsets count UTF-8 code units (e.g bytes).

Returns:

  • ('utf-8')
'utf-8'
UTF16 =

Character offsets count UTF-16 code units.

This is the default and must always be supported by servers

Returns:

  • ('utf-16')
'utf-16'
UTF32 =

Character offsets count UTF-32 code units.

Implementation note: these are the same as Unicode code points, so this PositionEncodingKind may also be used for an encoding-agnostic representation of character offsets.

Returns:

  • ('utf-32')
'utf-32'