Module: LanguageServer::Protocol::Constant::SemanticTokenModifiers

Defined in:
lib/language_server/protocol/constant/semantic_token_modifiers.rb

Overview

A set of predefined token modifiers. This set is not fixed an clients can specify additional token types via the corresponding client capabilities.

Since:

  • 3.16.0

Constant Summary collapse

DECLARATION =

Since:

  • 3.16.0

"declaration"
DEFINITION =

Since:

  • 3.16.0

"definition"
READONLY =

Since:

  • 3.16.0

"readonly"
STATIC =

Since:

  • 3.16.0

"static"
DEPRECATED =

Since:

  • 3.16.0

"deprecated"
ABSTRACT =

Since:

  • 3.16.0

"abstract"
ASYNC =

Since:

  • 3.16.0

"async"
MODIFICATION =

Since:

  • 3.16.0

"modification"
DOCUMENTATION =

Since:

  • 3.16.0

"documentation"
DEFAULT_LIBRARY =

Since:

  • 3.16.0

"defaultLibrary"