Module: LanguageServer::Protocol::Constant::SemanticTokenTypes

Defined in:
lib/language_server/protocol/constant/semantic_token_types.rb

Overview

A set of predefined token types. This set is not fixed an clients can specify additional token types via the corresponding client capabilities.

Since:

  • 3.16.0

Constant Summary collapse

NAMESPACE =

Since:

  • 3.16.0

"namespace"
TYPE =

Represents a generic type. Acts as a fallback for types which can’t be mapped to a specific type like class or enum.

Since:

  • 3.16.0

"type"
CLASS =

Since:

  • 3.16.0

"class"
ENUM =

Since:

  • 3.16.0

"enum"
INTERFACE =

Since:

  • 3.16.0

"interface"
STRUCT =

Since:

  • 3.16.0

"struct"
TYPE_PARAMETER =

Since:

  • 3.16.0

"typeParameter"
PARAMETER =

Since:

  • 3.16.0

"parameter"
VARIABLE =

Since:

  • 3.16.0

"variable"
PROPERTY =

Since:

  • 3.16.0

"property"
ENUM_MEMBER =

Since:

  • 3.16.0

"enumMember"
EVENT =

Since:

  • 3.16.0

"event"
FUNCTION =

Since:

  • 3.16.0

"function"
METHOD =

Since:

  • 3.16.0

"method"
MACRO =

Since:

  • 3.16.0

"macro"
KEYWORD =

Since:

  • 3.16.0

"keyword"
MODIFIER =

Since:

  • 3.16.0

"modifier"
COMMENT =

Since:

  • 3.16.0

"comment"
STRING =

Since:

  • 3.16.0

"string"
NUMBER =

Since:

  • 3.16.0

"number"
REGEXP =

Since:

  • 3.16.0

"regexp"
OPERATOR =

Since:

  • 3.16.0

"operator"
DECORATOR =

Since:

  • 3.17.0

"decorator"