Module: LanguageServer::Protocol::Constant::SignatureHelpTriggerKind

Defined in:
lib/language_server/protocol/constant/signature_help_trigger_kind.rb

Overview

How a signature help was triggered.

Since:

  • 3.15.0

Constant Summary collapse

INVOKED =

Signature help was invoked manually by the user or by a command.

Since:

  • 3.15.0

1
TRIGGER_CHARACTER =

Signature help was triggered by a trigger character.

Since:

  • 3.15.0

2
CONTENT_CHANGE =

Signature help was triggered by the cursor moving or by the document content changing.

Since:

  • 3.15.0

3