Module: LanguageServer::Protocol::Constant::SymbolTag

Defined in:
lib/language_server/protocol/constant/symbol_tag.rb,
sig/language_server/protocol/constant/symbol_tag.rbs

Overview

Symbol tags are extra annotations that tweak the rendering of a symbol.

Constant Summary collapse

DEPRECATED =

Render a symbol as obsolete, usually using a strike-out.

Returns:

  • (1)
1