Module: LanguageServer::Protocol::Constant::TextDocumentSyncKind

Defined in:
lib/language_server/protocol/constant/text_document_sync_kind.rb,
sig/language_server/protocol/constant/text_document_sync_kind.rbs

Overview

Defines how the host (editor) should sync document changes to the language server.

Constant Summary collapse

NONE =

Documents should not be synced at all.

Returns:

  • (0)
0
FULL =

Documents are synced by always sending the full content of the document.

Returns:

  • (1)
1
INCREMENTAL =

Documents are synced by sending the full content on open. After that only incremental updates to the document are sent.

Returns:

  • (2)
2