Module: LanguageServer::Protocol::Constant::UniquenessLevel

Defined in:
lib/language_server/protocol/constant/uniqueness_level.rb,
sig/language_server/protocol/constant/uniqueness_level.rbs

Overview

Moniker uniqueness level to define scope of the moniker.

Constant Summary collapse

DOCUMENT =

The moniker is only unique inside a document

Returns:

  • ('document')
'document'
PROJECT =

The moniker is unique inside a project for which a dump got created

Returns:

  • ('project')
'project'
GROUP =

The moniker is unique inside the group to which a project belongs

Returns:

  • ('group')
'group'
SCHEME =

The moniker is unique inside the moniker scheme.

Returns:

  • ('scheme')
'scheme'
GLOBAL =

The moniker is globally unique

Returns:

  • ('global')
'global'