Class: LanguageServer::Protocol::Interface::ApplyWorkspaceEditParams

Inherits:
Object
  • Object
show all
Defined in:
lib/language_server/protocol/interface/apply_workspace_edit_params.rb

Overview

The parameters passed via a apply workspace edit request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(label: nil, edit:) ⇒ ApplyWorkspaceEditParams

Returns a new instance of ApplyWorkspaceEditParams.



8
9
10
11
12
13
14
15
# File 'lib/language_server/protocol/interface/apply_workspace_edit_params.rb', line 8

def initialize(label: nil, edit:)
  @attributes = {}

  @attributes[:label] = label if label
  @attributes[:edit] = edit

  @attributes.freeze
end

Instance Attribute Details

#attributesObject (readonly)

Returns the value of attribute attributes.



35
36
37
# File 'lib/language_server/protocol/interface/apply_workspace_edit_params.rb', line 35

def attributes
  @attributes
end

Instance Method Details

#editWorkspaceEdit

The edits to apply.

Returns:



31
32
33
# File 'lib/language_server/protocol/interface/apply_workspace_edit_params.rb', line 31

def edit
  attributes.fetch(:edit)
end

#labelstring | nil

An optional label of the workspace edit. This label is presented in the user interface for example on an undo stack to undo the workspace edit.

Returns:

  • (string | nil)


23
24
25
# File 'lib/language_server/protocol/interface/apply_workspace_edit_params.rb', line 23

def label
  attributes.fetch(:label)
end

#to_hashObject



37
38
39
# File 'lib/language_server/protocol/interface/apply_workspace_edit_params.rb', line 37

def to_hash
  attributes
end

#to_json(*args) ⇒ Object



41
42
43
# File 'lib/language_server/protocol/interface/apply_workspace_edit_params.rb', line 41

def to_json(*args)
  to_hash.to_json(*args)
end