Class: LanguageServer::Protocol::Interface::CodeDescription

Inherits:
Object
  • Object
show all
Defined in:
lib/language_server/protocol/interface/code_description.rb,
sig/language_server/protocol/interface/code_description.rbs

Overview

Structure to capture a description for an error code.

Since:

  • 3.16.0

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(href:) ⇒ CodeDescription

Returns a new instance of CodeDescription.

Parameters:

  • href: (String)

Since:

  • 3.16.0



10
11
12
13
14
15
16
# File 'lib/language_server/protocol/interface/code_description.rb', line 10

def initialize(href:)
  @attributes = {}

  @attributes[:href] = href

  @attributes.freeze
end

Instance Attribute Details

#attributesHash[Symbol, untyped] (readonly)

Returns:

  • (Hash[Symbol, untyped])

Since:

  • 3.16.0



26
27
28
# File 'lib/language_server/protocol/interface/code_description.rb', line 26

def attributes
  @attributes
end

Instance Method Details

#hrefURI

An URI to open with more information about the diagnostic error.

Returns:

  • (URI)

Since:

  • 3.16.0



22
23
24
# File 'lib/language_server/protocol/interface/code_description.rb', line 22

def href
  attributes.fetch(:href)
end

#to_hashHash[Symbol, untyped]

Returns:

  • (Hash[Symbol, untyped])

Since:

  • 3.16.0



28
29
30
# File 'lib/language_server/protocol/interface/code_description.rb', line 28

def to_hash
  attributes
end

#to_json(*args) ⇒ String

Parameters:

  • (Object)

Returns:

  • (String)

Since:

  • 3.16.0



32
33
34
# File 'lib/language_server/protocol/interface/code_description.rb', line 32

def to_json(*args)
  to_hash.to_json(*args)
end