Method: LanguageServer::Protocol::Interface::CodeLensRegistrationOptions#document_selector

Defined in:
lib/language_server/protocol/interface/code_lens_registration_options.rb

#document_selectorDocumentSelector

A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.

Returns:

  • (DocumentSelector)


20
21
22
# File 'lib/language_server/protocol/interface/code_lens_registration_options.rb', line 20

def document_selector
  attributes.fetch(:documentSelector)
end