Class: LanguageServer::Protocol::Interface::ColorPresentationParams

Inherits:
Object
  • Object
show all
Defined in:
lib/language_server/protocol/interface/color_presentation_params.rb,
sig/language_server/protocol/interface/color_presentation_params.rbs

Overview

Parameters for a ColorPresentationRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(text_document:, color:, range:, work_done_token: nil, partial_result_token: nil) ⇒ ColorPresentationParams

Returns a new instance of ColorPresentationParams.

Parameters:

  • text_document: (Object)
  • color: (Object)
  • range: (Object)
  • work_done_token: (Object) (defaults to: nil)
  • partial_result_token: (Object) (defaults to: nil)


8
9
10
11
12
13
14
15
16
17
18
# File 'lib/language_server/protocol/interface/color_presentation_params.rb', line 8

def initialize(text_document:, color:, range:, work_done_token: nil, partial_result_token: nil)
  @attributes = {}

  @attributes[:textDocument] = text_document
  @attributes[:color] = color
  @attributes[:range] = range
  @attributes[:workDoneToken] = work_done_token if work_done_token
  @attributes[:partialResultToken] = partial_result_token if partial_result_token

  @attributes.freeze
end

Instance Attribute Details

#attributesHash[Symbol, untyped] (readonly)

Returns the value of attribute attributes.

Returns:

  • (Hash[Symbol, untyped])


61
62
63
# File 'lib/language_server/protocol/interface/color_presentation_params.rb', line 61

def attributes
  @attributes
end

Instance Method Details

#colorColor

The color to request presentations for.

Returns:



32
33
34
# File 'lib/language_server/protocol/interface/color_presentation_params.rb', line 32

def color
  attributes.fetch(:color)
end

#partial_result_tokenProgressToken

An optional token that a server can use to report partial results (e.g. streaming) to the client.

Returns:

  • (ProgressToken)


57
58
59
# File 'lib/language_server/protocol/interface/color_presentation_params.rb', line 57

def partial_result_token
  attributes.fetch(:partialResultToken)
end

#rangeRange

The range where the color would be inserted. Serves as a context.

Returns:



40
41
42
# File 'lib/language_server/protocol/interface/color_presentation_params.rb', line 40

def range
  attributes.fetch(:range)
end

#text_documentTextDocumentIdentifier

The text document.



24
25
26
# File 'lib/language_server/protocol/interface/color_presentation_params.rb', line 24

def text_document
  attributes.fetch(:textDocument)
end

#to_hashHash[Symbol, untyped]

Returns:

  • (Hash[Symbol, untyped])


63
64
65
# File 'lib/language_server/protocol/interface/color_presentation_params.rb', line 63

def to_hash
  attributes
end

#to_json(*args) ⇒ String

Parameters:

  • (Object)

Returns:

  • (String)


67
68
69
# File 'lib/language_server/protocol/interface/color_presentation_params.rb', line 67

def to_json(*args)
  to_hash.to_json(*args)
end

#work_done_tokenProgressToken

An optional token that a server can use to report work done progress.

Returns:

  • (ProgressToken)


48
49
50
# File 'lib/language_server/protocol/interface/color_presentation_params.rb', line 48

def work_done_token
  attributes.fetch(:workDoneToken)
end