Class: LanguageServer::Protocol::Interface::CompletionOptions
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::CompletionOptions
- Defined in:
- lib/language_server/protocol/interface/completion_options.rb
Overview
Completion options.
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
Instance Method Summary collapse
-
#all_commit_characters ⇒ string[]
The list of all possible characters that commit a completion.
-
#initialize(work_done_progress: nil, trigger_characters: nil, all_commit_characters: nil, resolve_provider: nil) ⇒ CompletionOptions
constructor
A new instance of CompletionOptions.
-
#resolve_provider ⇒ boolean
The server provides support to resolve additional information for a completion item.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
-
#trigger_characters ⇒ string[]
Most tools trigger completion request automatically without explicitly requesting it using a keyboard shortcut (e.g. Ctrl+Space).
- #work_done_progress ⇒ boolean
Constructor Details
#initialize(work_done_progress: nil, trigger_characters: nil, all_commit_characters: nil, resolve_provider: nil) ⇒ CompletionOptions
Returns a new instance of CompletionOptions.
8 9 10 11 12 13 14 15 16 17 |
# File 'lib/language_server/protocol/interface/completion_options.rb', line 8 def initialize(work_done_progress: nil, trigger_characters: nil, all_commit_characters: nil, resolve_provider: nil) @attributes = {} @attributes[:workDoneProgress] = work_done_progress if work_done_progress @attributes[:triggerCharacters] = trigger_characters if trigger_characters @attributes[:allCommitCharacters] = all_commit_characters if all_commit_characters @attributes[:resolveProvider] = resolve_provider if resolve_provider @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
64 65 66 |
# File 'lib/language_server/protocol/interface/completion_options.rb', line 64 def attributes @attributes end |
Instance Method Details
#all_commit_characters ⇒ string[]
The list of all possible characters that commit a completion. This field can be used if clients don’t support individual commit characters per completion item. See client capability completion.completionItem.commitCharactersSupport.
If a server provides both allCommitCharacters and commit characters on an individual completion item the ones on the completion item win.
51 52 53 |
# File 'lib/language_server/protocol/interface/completion_options.rb', line 51 def all_commit_characters attributes.fetch(:allCommitCharacters) end |
#resolve_provider ⇒ boolean
The server provides support to resolve additional information for a completion item.
60 61 62 |
# File 'lib/language_server/protocol/interface/completion_options.rb', line 60 def resolve_provider attributes.fetch(:resolveProvider) end |
#to_hash ⇒ Object
66 67 68 |
# File 'lib/language_server/protocol/interface/completion_options.rb', line 66 def to_hash attributes end |
#to_json(*args) ⇒ Object
70 71 72 |
# File 'lib/language_server/protocol/interface/completion_options.rb', line 70 def to_json(*args) to_hash.to_json(*args) end |
#trigger_characters ⇒ string[]
Most tools trigger completion request automatically without explicitly requesting it using a keyboard shortcut (e.g. Ctrl+Space). Typically they do so when the user starts to type an identifier. For example if the user types c in a JavaScript file code complete will automatically pop up present console besides others as a completion item. Characters that make up identifiers don’t need to be listed here.
If code complete should automatically be trigger on characters not being valid inside an identifier (for example . in JavaScript) list them in triggerCharacters.
37 38 39 |
# File 'lib/language_server/protocol/interface/completion_options.rb', line 37 def trigger_characters attributes.fetch(:triggerCharacters) end |
#work_done_progress ⇒ boolean
20 21 22 |
# File 'lib/language_server/protocol/interface/completion_options.rb', line 20 def work_done_progress attributes.fetch(:workDoneProgress) end |