Class: LanguageServer::Protocol::Interface::CompletionRegistrationOptions
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::CompletionRegistrationOptions
- Defined in:
- lib/language_server/protocol/interface/completion_registration_options.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
Instance Method Summary collapse
-
#all_commit_characters ⇒ string[]
The list of all possible characters that commit a completion.
-
#completion_item ⇒ { labelDetailsSupport?: boolean; }
The server supports the following
CompletionItemspecific capabilities. -
#document_selector ⇒ DocumentSelector
A document selector to identify the scope of the registration.
-
#initialize(document_selector:, work_done_progress: nil, trigger_characters: nil, all_commit_characters: nil, resolve_provider: nil, completion_item: nil) ⇒ CompletionRegistrationOptions
constructor
A new instance of CompletionRegistrationOptions.
-
#resolve_provider ⇒ boolean
The server provides support to resolve additional information for a completion item.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
-
#trigger_characters ⇒ string[]
Most tools trigger completion request automatically without explicitly requesting it using a keyboard shortcut (e.g. Ctrl+Space).
- #work_done_progress ⇒ boolean
Constructor Details
#initialize(document_selector:, work_done_progress: nil, trigger_characters: nil, all_commit_characters: nil, resolve_provider: nil, completion_item: nil) ⇒ CompletionRegistrationOptions
Returns a new instance of CompletionRegistrationOptions.
5 6 7 8 9 10 11 12 13 14 15 16 |
# File 'lib/language_server/protocol/interface/completion_registration_options.rb', line 5 def initialize(document_selector:, work_done_progress: nil, trigger_characters: nil, all_commit_characters: nil, resolve_provider: nil, completion_item: nil) @attributes = {} @attributes[:documentSelector] = document_selector @attributes[:workDoneProgress] = work_done_progress if work_done_progress @attributes[:triggerCharacters] = trigger_characters if trigger_characters @attributes[:allCommitCharacters] = all_commit_characters if all_commit_characters @attributes[:resolveProvider] = resolve_provider if resolve_provider @attributes[:completionItem] = completion_item if completion_item @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
81 82 83 |
# File 'lib/language_server/protocol/interface/completion_registration_options.rb', line 81 def attributes @attributes end |
Instance Method Details
#all_commit_characters ⇒ string[]
The list of all possible characters that commit a completion. This field can be used if clients don’t support individual commit characters per completion item. See client capability completion.completionItem.commitCharactersSupport.
If a server provides both allCommitCharacters and commit characters on an individual completion item the ones on the completion item win.
59 60 61 |
# File 'lib/language_server/protocol/interface/completion_registration_options.rb', line 59 def all_commit_characters attributes.fetch(:allCommitCharacters) end |
#completion_item ⇒ { labelDetailsSupport?: boolean; }
The server supports the following CompletionItem specific capabilities.
77 78 79 |
# File 'lib/language_server/protocol/interface/completion_registration_options.rb', line 77 def completion_item attributes.fetch(:completionItem) end |
#document_selector ⇒ DocumentSelector
A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.
23 24 25 |
# File 'lib/language_server/protocol/interface/completion_registration_options.rb', line 23 def document_selector attributes.fetch(:documentSelector) end |
#resolve_provider ⇒ boolean
The server provides support to resolve additional information for a completion item.
68 69 70 |
# File 'lib/language_server/protocol/interface/completion_registration_options.rb', line 68 def resolve_provider attributes.fetch(:resolveProvider) end |
#to_hash ⇒ Object
83 84 85 |
# File 'lib/language_server/protocol/interface/completion_registration_options.rb', line 83 def to_hash attributes end |
#to_json(*args) ⇒ Object
87 88 89 |
# File 'lib/language_server/protocol/interface/completion_registration_options.rb', line 87 def to_json(*args) to_hash.to_json(*args) end |
#trigger_characters ⇒ string[]
Most tools trigger completion request automatically without explicitly requesting it using a keyboard shortcut (e.g. Ctrl+Space). Typically they do so when the user starts to type an identifier. For example if the user types c in a JavaScript file code complete will automatically pop up present console besides others as a completion item. Characters that make up identifiers don’t need to be listed here.
If code complete should automatically be trigger on characters not being valid inside an identifier (for example . in JavaScript) list them in triggerCharacters.
45 46 47 |
# File 'lib/language_server/protocol/interface/completion_registration_options.rb', line 45 def trigger_characters attributes.fetch(:triggerCharacters) end |
#work_done_progress ⇒ boolean
28 29 30 |
# File 'lib/language_server/protocol/interface/completion_registration_options.rb', line 28 def work_done_progress attributes.fetch(:workDoneProgress) end |