Class: LanguageServer::Protocol::Interface::Diagnostic

Inherits:
Object
  • Object
show all
Defined in:
lib/language_server/protocol/interface/diagnostic.rb,
sig/language_server/protocol/interface/diagnostic.rbs

Overview

Represents a diagnostic, such as a compiler error or warning. Diagnostic objects are only valid in the scope of a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(range:, severity: nil, code: nil, code_description: nil, source: nil, message:, tags: nil, related_information: nil, data: nil) ⇒ Diagnostic

Returns a new instance of Diagnostic.

Parameters:

  • range: (Object)
  • severity: (Object) (defaults to: nil)
  • code: (Integer, String) (defaults to: nil)
  • code_description: (Object) (defaults to: nil)
  • source: (String) (defaults to: nil)
  • message: (String)
  • tags: (Array[untyped]) (defaults to: nil)
  • related_information: (Array[untyped]) (defaults to: nil)
  • data: (Object) (defaults to: nil)


9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
# File 'lib/language_server/protocol/interface/diagnostic.rb', line 9

def initialize(range:, severity: nil, code: nil, code_description: nil, source: nil, message:, tags: nil, related_information: nil, data: nil)
  @attributes = {}

  @attributes[:range] = range
  @attributes[:severity] = severity if severity
  @attributes[:code] = code if code
  @attributes[:codeDescription] = code_description if code_description
  @attributes[:source] = source if source
  @attributes[:message] = message
  @attributes[:tags] = tags if tags
  @attributes[:relatedInformation] = related_information if related_information
  @attributes[:data] = data if data

  @attributes.freeze
end

Instance Attribute Details

#attributesHash[Symbol, untyped] (readonly)

Returns the value of attribute attributes.

Returns:

  • (Hash[Symbol, untyped])


109
110
111
# File 'lib/language_server/protocol/interface/diagnostic.rb', line 109

def attributes
  @attributes
end

Instance Method Details

#codeinteger | string

The diagnostic's code, which usually appear in the user interface.

Returns:

  • (integer | string)


46
47
48
# File 'lib/language_server/protocol/interface/diagnostic.rb', line 46

def code
  attributes.fetch(:code)
end

#code_descriptionCodeDescription

An optional property to describe the error code. Requires the code field (above) to be present/not null.

Returns:

Since:

  • 3.16.0



57
58
59
# File 'lib/language_server/protocol/interface/diagnostic.rb', line 57

def code_description
  attributes.fetch(:codeDescription)
end

#dataLSPAny

A data entry field that is preserved between a textDocument/publishDiagnostics notification and textDocument/codeAction request.

Returns:

  • (LSPAny)

Since:

  • 3.16.0



105
106
107
# File 'lib/language_server/protocol/interface/diagnostic.rb', line 105

def data
  attributes.fetch(:data)
end

#messagestring

The diagnostic's message. It usually appears in the user interface

Returns:

  • (string)


75
76
77
# File 'lib/language_server/protocol/interface/diagnostic.rb', line 75

def message
  attributes.fetch(:message)
end

#rangeRange

The range at which the message applies

Returns:



29
30
31
# File 'lib/language_server/protocol/interface/diagnostic.rb', line 29

def range
  attributes.fetch(:range)
end

An array of related diagnostic information, e.g. when symbol-names within a scope collide all definitions can be marked via this property.



94
95
96
# File 'lib/language_server/protocol/interface/diagnostic.rb', line 94

def related_information
  attributes.fetch(:relatedInformation)
end

#severityDiagnosticSeverity

The diagnostic's severity. Can be omitted. If omitted it is up to the client to interpret diagnostics as error, warning, info or hint.

Returns:

  • (DiagnosticSeverity)


38
39
40
# File 'lib/language_server/protocol/interface/diagnostic.rb', line 38

def severity
  attributes.fetch(:severity)
end

#sourcestring

A human-readable string describing the source of this diagnostic, e.g. 'typescript' or 'super lint'. It usually appears in the user interface.

Returns:

  • (string)


67
68
69
# File 'lib/language_server/protocol/interface/diagnostic.rb', line 67

def source
  attributes.fetch(:source)
end

#tagsDiagnosticTag[]

Additional metadata about the diagnostic.

Returns:

  • (DiagnosticTag[])

Since:

  • 3.15.0



85
86
87
# File 'lib/language_server/protocol/interface/diagnostic.rb', line 85

def tags
  attributes.fetch(:tags)
end

#to_hashHash[Symbol, untyped]

Returns:

  • (Hash[Symbol, untyped])


111
112
113
# File 'lib/language_server/protocol/interface/diagnostic.rb', line 111

def to_hash
  attributes
end

#to_json(*args) ⇒ String

Parameters:

  • (Object)

Returns:

  • (String)


115
116
117
# File 'lib/language_server/protocol/interface/diagnostic.rb', line 115

def to_json(*args)
  to_hash.to_json(*args)
end