Class: LanguageServer::Protocol::Interface::DiagnosticClientCapabilities

Inherits:
Object
  • Object
show all
Defined in:
lib/language_server/protocol/interface/diagnostic_client_capabilities.rb

Overview

Client capabilities specific to diagnostic pull requests.

Since:

  • 3.17.0

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(dynamic_registration: nil, related_document_support: nil) ⇒ DiagnosticClientCapabilities

Returns a new instance of DiagnosticClientCapabilities.

Since:

  • 3.17.0



10
11
12
13
14
15
16
17
# File 'lib/language_server/protocol/interface/diagnostic_client_capabilities.rb', line 10

def initialize(dynamic_registration: nil, related_document_support: nil)
  @attributes = {}

  @attributes[:dynamicRegistration] = dynamic_registration if dynamic_registration
  @attributes[:relatedDocumentSupport] = related_document_support if related_document_support

  @attributes.freeze
end

Instance Attribute Details

#attributesObject (readonly)

Since:

  • 3.17.0



37
38
39
# File 'lib/language_server/protocol/interface/diagnostic_client_capabilities.rb', line 37

def attributes
  @attributes
end

Instance Method Details

#dynamic_registrationboolean | nil

Whether implementation supports dynamic registration. If this is set to true the client supports the new ‘(TextDocumentRegistrationOptions & StaticRegistrationOptions)` return value for the corresponding server capability as well.

Returns:

  • (boolean | nil)

Since:

  • 3.17.0



25
26
27
# File 'lib/language_server/protocol/interface/diagnostic_client_capabilities.rb', line 25

def dynamic_registration
  attributes.fetch(:dynamicRegistration)
end

Whether the clients supports related documents for document diagnostic pulls.

Returns:

  • (boolean | nil)

Since:

  • 3.17.0



33
34
35
# File 'lib/language_server/protocol/interface/diagnostic_client_capabilities.rb', line 33

def related_document_support
  attributes.fetch(:relatedDocumentSupport)
end

#to_hashObject

Since:

  • 3.17.0



39
40
41
# File 'lib/language_server/protocol/interface/diagnostic_client_capabilities.rb', line 39

def to_hash
  attributes
end

#to_json(*args) ⇒ Object

Since:

  • 3.17.0



43
44
45
# File 'lib/language_server/protocol/interface/diagnostic_client_capabilities.rb', line 43

def to_json(*args)
  to_hash.to_json(*args)
end