Class: LanguageServer::Protocol::Interface::DiagnosticRegistrationOptions

Inherits:
Object
  • Object
show all
Defined in:
lib/language_server/protocol/interface/diagnostic_registration_options.rb

Overview

Diagnostic registration options.

Since:

  • 3.17.0

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(document_selector:, identifier: nil, inter_file_dependencies:, workspace_diagnostics:, work_done_progress: nil, id: nil) ⇒ DiagnosticRegistrationOptions

Returns a new instance of DiagnosticRegistrationOptions.

Since:

  • 3.17.0



10
11
12
13
14
15
16
17
18
19
20
21
# File 'lib/language_server/protocol/interface/diagnostic_registration_options.rb', line 10

def initialize(document_selector:, identifier: nil, inter_file_dependencies:, workspace_diagnostics:, work_done_progress: nil, id: nil)
  @attributes = {}

  @attributes[:documentSelector] = document_selector
  @attributes[:identifier] = identifier if identifier
  @attributes[:interFileDependencies] = inter_file_dependencies
  @attributes[:workspaceDiagnostics] = workspace_diagnostics
  @attributes[:workDoneProgress] = work_done_progress if work_done_progress
  @attributes[:id] = id if id

  @attributes.freeze
end

Instance Attribute Details

#attributesObject (readonly)

Since:

  • 3.17.0



74
75
76
# File 'lib/language_server/protocol/interface/diagnostic_registration_options.rb', line 74

def attributes
  @attributes
end

Instance Method Details

#document_selectorDocumentSelector | null

A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.

Since:

  • 3.17.0



28
29
30
# File 'lib/language_server/protocol/interface/diagnostic_registration_options.rb', line 28

def document_selector
  attributes.fetch(:documentSelector)
end

#idstring | nil

The id used to register the request. The id can be used to deregister the request again. See also Registration#id.

Since:

  • 3.17.0



70
71
72
# File 'lib/language_server/protocol/interface/diagnostic_registration_options.rb', line 70

def id
  attributes.fetch(:id)
end

#identifierstring | nil

An optional identifier under which the diagnostics are managed by the client.

Since:

  • 3.17.0



37
38
39
# File 'lib/language_server/protocol/interface/diagnostic_registration_options.rb', line 37

def identifier
  attributes.fetch(:identifier)
end

#inter_file_dependenciesboolean

Whether the language has inter file dependencies meaning that editing code in one file can result in a different diagnostic set in another file. Inter file dependencies are common for most programming languages and typically uncommon for linters.

Since:

  • 3.17.0



48
49
50
# File 'lib/language_server/protocol/interface/diagnostic_registration_options.rb', line 48

def inter_file_dependencies
  attributes.fetch(:interFileDependencies)
end

#to_hashObject

Since:

  • 3.17.0



76
77
78
# File 'lib/language_server/protocol/interface/diagnostic_registration_options.rb', line 76

def to_hash
  attributes
end

#to_json(*args) ⇒ Object

Since:

  • 3.17.0



80
81
82
# File 'lib/language_server/protocol/interface/diagnostic_registration_options.rb', line 80

def to_json(*args)
  to_hash.to_json(*args)
end

#work_done_progressboolean | nil

Since:

  • 3.17.0



61
62
63
# File 'lib/language_server/protocol/interface/diagnostic_registration_options.rb', line 61

def work_done_progress
  attributes.fetch(:workDoneProgress)
end

#workspace_diagnosticsboolean

The server provides support for workspace diagnostics as well.

Since:

  • 3.17.0



56
57
58
# File 'lib/language_server/protocol/interface/diagnostic_registration_options.rb', line 56

def workspace_diagnostics
  attributes.fetch(:workspaceDiagnostics)
end