Class: LanguageServer::Protocol::Interface::DidCloseNotebookDocumentParams
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::DidCloseNotebookDocumentParams
- Defined in:
- lib/language_server/protocol/interface/did_close_notebook_document_params.rb
Overview
The params sent in a close notebook document notification.
Instance Attribute Summary collapse
- #attributes ⇒ Object readonly
Instance Method Summary collapse
-
#cell_text_documents ⇒ TextDocumentIdentifier[]
The text documents that represent the content of a notebook cell that got closed.
-
#initialize(notebook_document:, cell_text_documents:) ⇒ DidCloseNotebookDocumentParams
constructor
A new instance of DidCloseNotebookDocumentParams.
-
#notebook_document ⇒ NotebookDocumentIdentifier
The notebook document that got closed.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
Constructor Details
#initialize(notebook_document:, cell_text_documents:) ⇒ DidCloseNotebookDocumentParams
Returns a new instance of DidCloseNotebookDocumentParams.
10 11 12 13 14 15 16 17 |
# File 'lib/language_server/protocol/interface/did_close_notebook_document_params.rb', line 10 def initialize(notebook_document:, cell_text_documents:) @attributes = {} @attributes[:notebookDocument] = notebook_document @attributes[:cellTextDocuments] = cell_text_documents @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
36 37 38 |
# File 'lib/language_server/protocol/interface/did_close_notebook_document_params.rb', line 36 def attributes @attributes end |
Instance Method Details
#cell_text_documents ⇒ TextDocumentIdentifier[]
The text documents that represent the content of a notebook cell that got closed.
32 33 34 |
# File 'lib/language_server/protocol/interface/did_close_notebook_document_params.rb', line 32 def cell_text_documents attributes.fetch(:cellTextDocuments) end |
#notebook_document ⇒ NotebookDocumentIdentifier
The notebook document that got closed.
23 24 25 |
# File 'lib/language_server/protocol/interface/did_close_notebook_document_params.rb', line 23 def notebook_document attributes.fetch(:notebookDocument) end |
#to_hash ⇒ Object
38 39 40 |
# File 'lib/language_server/protocol/interface/did_close_notebook_document_params.rb', line 38 def to_hash attributes end |
#to_json(*args) ⇒ Object
42 43 44 |
# File 'lib/language_server/protocol/interface/did_close_notebook_document_params.rb', line 42 def to_json(*args) to_hash.to_json(*args) end |