Class: LanguageServer::Protocol::Interface::DocumentColorClientCapabilities
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::DocumentColorClientCapabilities
- Defined in:
- lib/language_server/protocol/interface/document_color_client_capabilities.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
Instance Method Summary collapse
-
#dynamic_registration ⇒ boolean | nil
Whether implementation supports dynamic registration.
-
#initialize(dynamic_registration: nil) ⇒ DocumentColorClientCapabilities
constructor
A new instance of DocumentColorClientCapabilities.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
Constructor Details
#initialize(dynamic_registration: nil) ⇒ DocumentColorClientCapabilities
Returns a new instance of DocumentColorClientCapabilities.
5 6 7 8 9 10 11 |
# File 'lib/language_server/protocol/interface/document_color_client_capabilities.rb', line 5 def initialize(dynamic_registration: nil) @attributes = {} @attributes[:dynamicRegistration] = dynamic_registration if dynamic_registration @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
23 24 25 |
# File 'lib/language_server/protocol/interface/document_color_client_capabilities.rb', line 23 def attributes @attributes end |
Instance Method Details
#dynamic_registration ⇒ boolean | nil
Whether implementation supports dynamic registration. If this is set to true the client supports the new DocumentColorRegistrationOptions return value for the corresponding server capability as well.
19 20 21 |
# File 'lib/language_server/protocol/interface/document_color_client_capabilities.rb', line 19 def dynamic_registration attributes.fetch(:dynamicRegistration) end |
#to_hash ⇒ Object
25 26 27 |
# File 'lib/language_server/protocol/interface/document_color_client_capabilities.rb', line 25 def to_hash attributes end |
#to_json(*args) ⇒ Object
29 30 31 |
# File 'lib/language_server/protocol/interface/document_color_client_capabilities.rb', line 29 def to_json(*args) to_hash.to_json(*args) end |