Class: LanguageServer::Protocol::Interface::DocumentOnTypeFormattingParams

Inherits:
Object
  • Object
show all
Defined in:
lib/language_server/protocol/interface/document_on_type_formatting_params.rb,
sig/language_server/protocol/interface/document_on_type_formatting_params.rbs

Overview

The parameters of a DocumentOnTypeFormattingRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(text_document:, position:, ch:, options:) ⇒ DocumentOnTypeFormattingParams

Returns a new instance of DocumentOnTypeFormattingParams.

Parameters:

  • text_document: (Object)
  • position: (Object)
  • ch: (String)
  • options: (Object)


8
9
10
11
12
13
14
15
16
17
# File 'lib/language_server/protocol/interface/document_on_type_formatting_params.rb', line 8

def initialize(text_document:, position:, ch:, options:)
  @attributes = {}

  @attributes[:textDocument] = text_document
  @attributes[:position] = position
  @attributes[:ch] = ch
  @attributes[:options] = options

  @attributes.freeze
end

Instance Attribute Details

#attributesHash[Symbol, untyped] (readonly)

Returns the value of attribute attributes.

Returns:

  • (Hash[Symbol, untyped])


56
57
58
# File 'lib/language_server/protocol/interface/document_on_type_formatting_params.rb', line 56

def attributes
  @attributes
end

Instance Method Details

#chstring

The character that has been typed that triggered the formatting on type request. That is not necessarily the last character that got inserted into the document since the client could auto insert characters as well (e.g. like automatic brace completion).

Returns:

  • (string)


44
45
46
# File 'lib/language_server/protocol/interface/document_on_type_formatting_params.rb', line 44

def ch
  attributes.fetch(:ch)
end

#optionsFormattingOptions

The formatting options.

Returns:



52
53
54
# File 'lib/language_server/protocol/interface/document_on_type_formatting_params.rb', line 52

def options
  attributes.fetch(:options)
end

#positionPosition

The position around which the on type formatting should happen. This is not necessarily the exact position where the character denoted by the property ch got typed.

Returns:



33
34
35
# File 'lib/language_server/protocol/interface/document_on_type_formatting_params.rb', line 33

def position
  attributes.fetch(:position)
end

#text_documentTextDocumentIdentifier

The document to format.



23
24
25
# File 'lib/language_server/protocol/interface/document_on_type_formatting_params.rb', line 23

def text_document
  attributes.fetch(:textDocument)
end

#to_hashHash[Symbol, untyped]

Returns:

  • (Hash[Symbol, untyped])


58
59
60
# File 'lib/language_server/protocol/interface/document_on_type_formatting_params.rb', line 58

def to_hash
  attributes
end

#to_json(*args) ⇒ String

Parameters:

  • (Object)

Returns:

  • (String)


62
63
64
# File 'lib/language_server/protocol/interface/document_on_type_formatting_params.rb', line 62

def to_json(*args)
  to_hash.to_json(*args)
end