Class: LanguageServer::Protocol::Interface::DocumentRangeFormattingRegistrationOptions
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::DocumentRangeFormattingRegistrationOptions
- Defined in:
- lib/language_server/protocol/interface/document_range_formatting_registration_options.rb
Overview
Registration options for a [DocumentRangeFormattingRequest](#DocumentRangeFormattingRequest).
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
Instance Method Summary collapse
-
#document_selector ⇒ DocumentSelector | null
A document selector to identify the scope of the registration.
-
#initialize(document_selector:, work_done_progress: nil) ⇒ DocumentRangeFormattingRegistrationOptions
constructor
A new instance of DocumentRangeFormattingRegistrationOptions.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
- #work_done_progress ⇒ boolean | nil
Constructor Details
#initialize(document_selector:, work_done_progress: nil) ⇒ DocumentRangeFormattingRegistrationOptions
Returns a new instance of DocumentRangeFormattingRegistrationOptions.
8 9 10 11 12 13 14 15 |
# File 'lib/language_server/protocol/interface/document_range_formatting_registration_options.rb', line 8 def initialize(document_selector:, work_done_progress: nil) @attributes = {} @attributes[:documentSelector] = document_selector @attributes[:workDoneProgress] = work_done_progress if work_done_progress @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
31 32 33 |
# File 'lib/language_server/protocol/interface/document_range_formatting_registration_options.rb', line 31 def attributes @attributes end |
Instance Method Details
#document_selector ⇒ DocumentSelector | null
A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.
22 23 24 |
# File 'lib/language_server/protocol/interface/document_range_formatting_registration_options.rb', line 22 def document_selector attributes.fetch(:documentSelector) end |
#to_hash ⇒ Object
33 34 35 |
# File 'lib/language_server/protocol/interface/document_range_formatting_registration_options.rb', line 33 def to_hash attributes end |
#to_json(*args) ⇒ Object
37 38 39 |
# File 'lib/language_server/protocol/interface/document_range_formatting_registration_options.rb', line 37 def to_json(*args) to_hash.to_json(*args) end |
#work_done_progress ⇒ boolean | nil
27 28 29 |
# File 'lib/language_server/protocol/interface/document_range_formatting_registration_options.rb', line 27 def work_done_progress attributes.fetch(:workDoneProgress) end |