Class: LanguageServer::Protocol::Interface::DocumentSymbolOptions
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::DocumentSymbolOptions
- Defined in:
- lib/language_server/protocol/interface/document_symbol_options.rb
Overview
Provider options for a [DocumentSymbolRequest](#DocumentSymbolRequest).
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
Instance Method Summary collapse
-
#initialize(label: nil, work_done_progress: nil) ⇒ DocumentSymbolOptions
constructor
A new instance of DocumentSymbolOptions.
-
#label ⇒ string | nil
A human-readable string that is shown when multiple outlines trees are shown for the same document.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
- #work_done_progress ⇒ boolean | nil
Constructor Details
#initialize(label: nil, work_done_progress: nil) ⇒ DocumentSymbolOptions
Returns a new instance of DocumentSymbolOptions.
8 9 10 11 12 13 14 15 |
# File 'lib/language_server/protocol/interface/document_symbol_options.rb', line 8 def initialize(label: nil, work_done_progress: nil) @attributes = {} @attributes[:label] = label if label @attributes[:workDoneProgress] = work_done_progress if work_done_progress @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
33 34 35 |
# File 'lib/language_server/protocol/interface/document_symbol_options.rb', line 33 def attributes @attributes end |
Instance Method Details
#label ⇒ string | nil
A human-readable string that is shown when multiple outlines trees are shown for the same document.
24 25 26 |
# File 'lib/language_server/protocol/interface/document_symbol_options.rb', line 24 def label attributes.fetch(:label) end |
#to_hash ⇒ Object
35 36 37 |
# File 'lib/language_server/protocol/interface/document_symbol_options.rb', line 35 def to_hash attributes end |
#to_json(*args) ⇒ Object
39 40 41 |
# File 'lib/language_server/protocol/interface/document_symbol_options.rb', line 39 def to_json(*args) to_hash.to_json(*args) end |
#work_done_progress ⇒ boolean | nil
29 30 31 |
# File 'lib/language_server/protocol/interface/document_symbol_options.rb', line 29 def work_done_progress attributes.fetch(:workDoneProgress) end |