Class: LanguageServer::Protocol::Interface::FileOperationPattern

Inherits:
Object
  • Object
show all
Defined in:
lib/language_server/protocol/interface/file_operation_pattern.rb

Overview

A pattern to describe in which file operation requests or notifications the server is interested in receiving.

Since:

  • 3.16.0

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(glob:, matches: nil, options: nil) ⇒ FileOperationPattern

Returns a new instance of FileOperationPattern.

Since:

  • 3.16.0



11
12
13
14
15
16
17
18
19
# File 'lib/language_server/protocol/interface/file_operation_pattern.rb', line 11

def initialize(glob:, matches: nil, options: nil)
  @attributes = {}

  @attributes[:glob] = glob
  @attributes[:matches] = matches if matches
  @attributes[:options] = options if options

  @attributes.freeze
end

Instance Attribute Details

#attributesObject (readonly)

Since:

  • 3.16.0



53
54
55
# File 'lib/language_server/protocol/interface/file_operation_pattern.rb', line 53

def attributes
  @attributes
end

Instance Method Details

#globstring

The glob pattern to match. Glob patterns can have the following syntax:

  • ‘*` to match one or more characters in a path segment

  • ‘?` to match on one character in a path segment

  • ‘**` to match any number of path segments, including none

  • ‘{}` to group sub patterns into an OR expression. (e.g. `**​/*.ts,js` matches all TypeScript and JavaScript files)

  • [] to declare a range of characters to match in a path segment (e.g., example.[0-9] to match on example.0, example.1, …)

  • ‘[!…]` to negate a range of characters to match in a path segment (e.g., `example.` to match on example.a, example.b, but not example.0)

Since:

  • 3.16.0



31
32
33
# File 'lib/language_server/protocol/interface/file_operation_pattern.rb', line 31

def glob
  attributes.fetch(:glob)
end

#matchesFileOperationPatternKind | nil

Whether to match files or folders with this pattern.

Matches both if undefined.

Since:

  • 3.16.0



41
42
43
# File 'lib/language_server/protocol/interface/file_operation_pattern.rb', line 41

def matches
  attributes.fetch(:matches)
end

#optionsFileOperationPatternOptions | nil

Additional options used during matching.

Since:

  • 3.16.0



49
50
51
# File 'lib/language_server/protocol/interface/file_operation_pattern.rb', line 49

def options
  attributes.fetch(:options)
end

#to_hashObject

Since:

  • 3.16.0



55
56
57
# File 'lib/language_server/protocol/interface/file_operation_pattern.rb', line 55

def to_hash
  attributes
end

#to_json(*args) ⇒ Object

Since:

  • 3.16.0



59
60
61
# File 'lib/language_server/protocol/interface/file_operation_pattern.rb', line 59

def to_json(*args)
  to_hash.to_json(*args)
end