Class: LanguageServer::Protocol::Interface::ImplementationClientCapabilities
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::ImplementationClientCapabilities
- Defined in:
- lib/language_server/protocol/interface/implementation_client_capabilities.rb
Overview
Instance Attribute Summary collapse
- #attributes ⇒ Object readonly
Instance Method Summary collapse
-
#dynamic_registration ⇒ boolean | nil
Whether implementation supports dynamic registration.
-
#initialize(dynamic_registration: nil, link_support: nil) ⇒ ImplementationClientCapabilities
constructor
A new instance of ImplementationClientCapabilities.
-
#link_support ⇒ boolean | nil
The client supports additional metadata in the form of definition links.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
Constructor Details
#initialize(dynamic_registration: nil, link_support: nil) ⇒ ImplementationClientCapabilities
Returns a new instance of ImplementationClientCapabilities.
8 9 10 11 12 13 14 15 |
# File 'lib/language_server/protocol/interface/implementation_client_capabilities.rb', line 8 def initialize(dynamic_registration: nil, link_support: nil) @attributes = {} @attributes[:dynamicRegistration] = dynamic_registration if dynamic_registration @attributes[:linkSupport] = link_support if link_support @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
37 38 39 |
# File 'lib/language_server/protocol/interface/implementation_client_capabilities.rb', line 37 def attributes @attributes end |
Instance Method Details
#dynamic_registration ⇒ boolean | nil
Whether implementation supports dynamic registration. If this is set to true the client supports the new ImplementationRegistrationOptions return value for the corresponding server capability as well.
23 24 25 |
# File 'lib/language_server/protocol/interface/implementation_client_capabilities.rb', line 23 def dynamic_registration attributes.fetch(:dynamicRegistration) end |
#link_support ⇒ boolean | nil
The client supports additional metadata in the form of definition links.
33 34 35 |
# File 'lib/language_server/protocol/interface/implementation_client_capabilities.rb', line 33 def link_support attributes.fetch(:linkSupport) end |
#to_hash ⇒ Object
39 40 41 |
# File 'lib/language_server/protocol/interface/implementation_client_capabilities.rb', line 39 def to_hash attributes end |
#to_json(*args) ⇒ Object
43 44 45 |
# File 'lib/language_server/protocol/interface/implementation_client_capabilities.rb', line 43 def to_json(*args) to_hash.to_json(*args) end |