Class: LanguageServer::Protocol::Interface::InitializeError
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::InitializeError
- Defined in:
- lib/language_server/protocol/interface/initialize_error.rb
Overview
The data type of the ResponseError if the initialize request fails.
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
Instance Method Summary collapse
-
#initialize(retry:) ⇒ InitializeError
constructor
A new instance of InitializeError.
-
#retry ⇒ boolean
Indicates whether the client execute the following retry logic: (1) show the message provided by the ResponseError to the user (2) user selects retry or cancel (3) if user selected retry the initialize method is sent again.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
Constructor Details
#initialize(retry:) ⇒ InitializeError
Returns a new instance of InitializeError.
9 10 11 12 13 14 15 |
# File 'lib/language_server/protocol/interface/initialize_error.rb', line 9 def initialize(retry:) @attributes = {} @attributes[:retry] = binding.local_variable_get(:retry) @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
28 29 30 |
# File 'lib/language_server/protocol/interface/initialize_error.rb', line 28 def attributes @attributes end |
Instance Method Details
#retry ⇒ boolean
Indicates whether the client execute the following retry logic: (1) show the message provided by the ResponseError to the user (2) user selects retry or cancel (3) if user selected retry the initialize method is sent again.
24 25 26 |
# File 'lib/language_server/protocol/interface/initialize_error.rb', line 24 def retry attributes.fetch(:retry) end |
#to_hash ⇒ Object
30 31 32 |
# File 'lib/language_server/protocol/interface/initialize_error.rb', line 30 def to_hash attributes end |
#to_json(*args) ⇒ Object
34 35 36 |
# File 'lib/language_server/protocol/interface/initialize_error.rb', line 34 def to_json(*args) to_hash.to_json(*args) end |