Class: LanguageServer::Protocol::Interface::InlayHintClientCapabilities
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::InlayHintClientCapabilities
- Defined in:
- lib/language_server/protocol/interface/inlay_hint_client_capabilities.rb,
sig/language_server/protocol/interface/inlay_hint_client_capabilities.rbs
Overview
Inlay hint client capabilities.
Instance Attribute Summary collapse
- #attributes ⇒ Hash[Symbol, untyped] readonly
Instance Method Summary collapse
-
#dynamic_registration ⇒ boolean
Whether inlay hints support dynamic registration.
-
#initialize(dynamic_registration: nil, resolve_support: nil) ⇒ InlayHintClientCapabilities
constructor
A new instance of InlayHintClientCapabilities.
-
#resolve_support ⇒ { properties: string[]; }
Indicates which properties a client can resolve lazily on an inlay hint.
- #to_hash ⇒ Hash[Symbol, untyped]
- #to_json(*args) ⇒ String
Constructor Details
#initialize(dynamic_registration: nil, resolve_support: nil) ⇒ InlayHintClientCapabilities
Returns a new instance of InlayHintClientCapabilities.
10 11 12 13 14 15 16 17 |
# File 'lib/language_server/protocol/interface/inlay_hint_client_capabilities.rb', line 10 def initialize(dynamic_registration: nil, resolve_support: nil) @attributes = {} @attributes[:dynamicRegistration] = dynamic_registration if dynamic_registration @attributes[:resolveSupport] = resolve_support if resolve_support @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Hash[Symbol, untyped] (readonly)
36 37 38 |
# File 'lib/language_server/protocol/interface/inlay_hint_client_capabilities.rb', line 36 def attributes @attributes end |
Instance Method Details
#dynamic_registration ⇒ boolean
Whether inlay hints support dynamic registration.
23 24 25 |
# File 'lib/language_server/protocol/interface/inlay_hint_client_capabilities.rb', line 23 def dynamic_registration attributes.fetch(:dynamicRegistration) end |
#resolve_support ⇒ { properties: string[]; }
Indicates which properties a client can resolve lazily on an inlay hint.
32 33 34 |
# File 'lib/language_server/protocol/interface/inlay_hint_client_capabilities.rb', line 32 def resolve_support attributes.fetch(:resolveSupport) end |
#to_hash ⇒ Hash[Symbol, untyped]
38 39 40 |
# File 'lib/language_server/protocol/interface/inlay_hint_client_capabilities.rb', line 38 def to_hash attributes end |
#to_json(*args) ⇒ String
42 43 44 |
# File 'lib/language_server/protocol/interface/inlay_hint_client_capabilities.rb', line 42 def to_json(*args) to_hash.to_json(*args) end |