Class: LanguageServer::Protocol::Interface::InlayHintRegistrationOptions
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::InlayHintRegistrationOptions
- Defined in:
- lib/language_server/protocol/interface/inlay_hint_registration_options.rb
Overview
Inlay hint options used during static or dynamic registration.
Instance Attribute Summary collapse
- #attributes ⇒ Object readonly
Instance Method Summary collapse
-
#document_selector ⇒ DocumentSelector | null
A document selector to identify the scope of the registration.
-
#id ⇒ string | nil
The id used to register the request.
-
#initialize(resolve_provider: nil, work_done_progress: nil, document_selector:, id: nil) ⇒ InlayHintRegistrationOptions
constructor
A new instance of InlayHintRegistrationOptions.
-
#resolve_provider ⇒ boolean | nil
The server provides support to resolve additional information for an inlay hint item.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
- #work_done_progress ⇒ boolean | nil
Constructor Details
#initialize(resolve_provider: nil, work_done_progress: nil, document_selector:, id: nil) ⇒ InlayHintRegistrationOptions
Returns a new instance of InlayHintRegistrationOptions.
10 11 12 13 14 15 16 17 18 19 |
# File 'lib/language_server/protocol/interface/inlay_hint_registration_options.rb', line 10 def initialize(resolve_provider: nil, work_done_progress: nil, document_selector:, id: nil) @attributes = {} @attributes[:resolveProvider] = resolve_provider if resolve_provider @attributes[:workDoneProgress] = work_done_progress if work_done_progress @attributes[:documentSelector] = document_selector @attributes[:id] = id if id @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
53 54 55 |
# File 'lib/language_server/protocol/interface/inlay_hint_registration_options.rb', line 53 def attributes @attributes end |
Instance Method Details
#document_selector ⇒ DocumentSelector | null
A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.
40 41 42 |
# File 'lib/language_server/protocol/interface/inlay_hint_registration_options.rb', line 40 def document_selector attributes.fetch(:documentSelector) end |
#id ⇒ string | nil
The id used to register the request. The id can be used to deregister the request again. See also Registration#id.
49 50 51 |
# File 'lib/language_server/protocol/interface/inlay_hint_registration_options.rb', line 49 def id attributes.fetch(:id) end |
#resolve_provider ⇒ boolean | nil
The server provides support to resolve additional information for an inlay hint item.
26 27 28 |
# File 'lib/language_server/protocol/interface/inlay_hint_registration_options.rb', line 26 def resolve_provider attributes.fetch(:resolveProvider) end |
#to_hash ⇒ Object
55 56 57 |
# File 'lib/language_server/protocol/interface/inlay_hint_registration_options.rb', line 55 def to_hash attributes end |
#to_json(*args) ⇒ Object
59 60 61 |
# File 'lib/language_server/protocol/interface/inlay_hint_registration_options.rb', line 59 def to_json(*args) to_hash.to_json(*args) end |
#work_done_progress ⇒ boolean | nil
31 32 33 |
# File 'lib/language_server/protocol/interface/inlay_hint_registration_options.rb', line 31 def work_done_progress attributes.fetch(:workDoneProgress) end |