Class: LanguageServer::Protocol::Interface::InlineValueText
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::InlineValueText
- Defined in:
- lib/language_server/protocol/interface/inline_value_text.rb
Overview
Provide inline value as text.
Instance Attribute Summary collapse
- #attributes ⇒ Object readonly
Instance Method Summary collapse
-
#initialize(range:, text:) ⇒ InlineValueText
constructor
A new instance of InlineValueText.
-
#range ⇒ Range
The document range for which the inline value applies.
-
#text ⇒ string
The text of the inline value.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
Constructor Details
#initialize(range:, text:) ⇒ InlineValueText
Returns a new instance of InlineValueText.
10 11 12 13 14 15 16 17 |
# File 'lib/language_server/protocol/interface/inline_value_text.rb', line 10 def initialize(range:, text:) @attributes = {} @attributes[:range] = range @attributes[:text] = text @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
35 36 37 |
# File 'lib/language_server/protocol/interface/inline_value_text.rb', line 35 def attributes @attributes end |
Instance Method Details
#range ⇒ Range
The document range for which the inline value applies.
23 24 25 |
# File 'lib/language_server/protocol/interface/inline_value_text.rb', line 23 def range attributes.fetch(:range) end |
#text ⇒ string
The text of the inline value.
31 32 33 |
# File 'lib/language_server/protocol/interface/inline_value_text.rb', line 31 def text attributes.fetch(:text) end |
#to_hash ⇒ Object
37 38 39 |
# File 'lib/language_server/protocol/interface/inline_value_text.rb', line 37 def to_hash attributes end |
#to_json(*args) ⇒ Object
41 42 43 |
# File 'lib/language_server/protocol/interface/inline_value_text.rb', line 41 def to_json(*args) to_hash.to_json(*args) end |