Class: LanguageServer::Protocol::Interface::InlineValueWorkspaceClientCapabilities
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::InlineValueWorkspaceClientCapabilities
- Defined in:
- lib/language_server/protocol/interface/inline_value_workspace_client_capabilities.rb
Overview
Client workspace capabilities specific to inline values.
Instance Attribute Summary collapse
- #attributes ⇒ Object readonly
Instance Method Summary collapse
-
#initialize(refresh_support: nil) ⇒ InlineValueWorkspaceClientCapabilities
constructor
A new instance of InlineValueWorkspaceClientCapabilities.
-
#refresh_support ⇒ boolean | nil
Whether the client implementation supports a refresh request sent from the server to the client.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
Constructor Details
#initialize(refresh_support: nil) ⇒ InlineValueWorkspaceClientCapabilities
Returns a new instance of InlineValueWorkspaceClientCapabilities.
10 11 12 13 14 15 16 |
# File 'lib/language_server/protocol/interface/inline_value_workspace_client_capabilities.rb', line 10 def initialize(refresh_support: nil) @attributes = {} @attributes[:refreshSupport] = refresh_support if refresh_support @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
32 33 34 |
# File 'lib/language_server/protocol/interface/inline_value_workspace_client_capabilities.rb', line 32 def attributes @attributes end |
Instance Method Details
#refresh_support ⇒ boolean | nil
Whether the client implementation supports a refresh request sent from the server to the client.
Note that this event is global and will force the client to refresh all inline values currently shown. It should be used with absolute care and is useful for situation where a server for example detects a project wide change that requires such a calculation.
28 29 30 |
# File 'lib/language_server/protocol/interface/inline_value_workspace_client_capabilities.rb', line 28 def refresh_support attributes.fetch(:refreshSupport) end |
#to_hash ⇒ Object
34 35 36 |
# File 'lib/language_server/protocol/interface/inline_value_workspace_client_capabilities.rb', line 34 def to_hash attributes end |
#to_json(*args) ⇒ Object
38 39 40 |
# File 'lib/language_server/protocol/interface/inline_value_workspace_client_capabilities.rb', line 38 def to_json(*args) to_hash.to_json(*args) end |