Class: LanguageServer::Protocol::Interface::NotebookDocumentSyncClientCapabilities

Inherits:
Object
  • Object
show all
Defined in:
lib/language_server/protocol/interface/notebook_document_sync_client_capabilities.rb

Overview

Notebook specific client capabilities.

Since:

  • 3.17.0

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(dynamic_registration: nil, execution_summary_support: nil) ⇒ NotebookDocumentSyncClientCapabilities

Returns a new instance of NotebookDocumentSyncClientCapabilities.

Since:

  • 3.17.0



10
11
12
13
14
15
16
17
# File 'lib/language_server/protocol/interface/notebook_document_sync_client_capabilities.rb', line 10

def initialize(dynamic_registration: nil, execution_summary_support: nil)
  @attributes = {}

  @attributes[:dynamicRegistration] = dynamic_registration if dynamic_registration
  @attributes[:executionSummarySupport] = execution_summary_support if execution_summary_support

  @attributes.freeze
end

Instance Attribute Details

#attributesObject (readonly)

Since:

  • 3.17.0



38
39
40
# File 'lib/language_server/protocol/interface/notebook_document_sync_client_capabilities.rb', line 38

def attributes
  @attributes
end

Instance Method Details

#dynamic_registrationboolean | nil

Whether implementation supports dynamic registration. If this is set to true the client supports the new ‘(TextDocumentRegistrationOptions & StaticRegistrationOptions)` return value for the corresponding server capability as well.

Returns:

  • (boolean | nil)

Since:

  • 3.17.0



26
27
28
# File 'lib/language_server/protocol/interface/notebook_document_sync_client_capabilities.rb', line 26

def dynamic_registration
  attributes.fetch(:dynamicRegistration)
end

#execution_summary_supportboolean | nil

The client supports sending execution summary data per cell.

Returns:

  • (boolean | nil)

Since:

  • 3.17.0



34
35
36
# File 'lib/language_server/protocol/interface/notebook_document_sync_client_capabilities.rb', line 34

def execution_summary_support
  attributes.fetch(:executionSummarySupport)
end

#to_hashObject

Since:

  • 3.17.0



40
41
42
# File 'lib/language_server/protocol/interface/notebook_document_sync_client_capabilities.rb', line 40

def to_hash
  attributes
end

#to_json(*args) ⇒ Object

Since:

  • 3.17.0



44
45
46
# File 'lib/language_server/protocol/interface/notebook_document_sync_client_capabilities.rb', line 44

def to_json(*args)
  to_hash.to_json(*args)
end