Class: LanguageServer::Protocol::Interface::OptionalVersionedTextDocumentIdentifier

Inherits:
Object
  • Object
show all
Defined in:
lib/language_server/protocol/interface/optional_versioned_text_document_identifier.rb,
sig/language_server/protocol/interface/optional_versioned_text_document_identifier.rbs

Overview

A text document identifier to optionally denote a specific version of a text document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(version:, uri:) ⇒ OptionalVersionedTextDocumentIdentifier

Returns a new instance of OptionalVersionedTextDocumentIdentifier.

Parameters:

  • version: (Integer, nil)
  • uri: (String)


8
9
10
11
12
13
14
15
# File 'lib/language_server/protocol/interface/optional_versioned_text_document_identifier.rb', line 8

def initialize(version:, uri:)
  @attributes = {}

  @attributes[:version] = version
  @attributes[:uri] = uri

  @attributes.freeze
end

Instance Attribute Details

#attributesHash[Symbol, untyped] (readonly)

Returns the value of attribute attributes.

Returns:

  • (Hash[Symbol, untyped])


37
38
39
# File 'lib/language_server/protocol/interface/optional_versioned_text_document_identifier.rb', line 37

def attributes
  @attributes
end

Instance Method Details

#to_hashHash[Symbol, untyped]

Returns:

  • (Hash[Symbol, untyped])


39
40
41
# File 'lib/language_server/protocol/interface/optional_versioned_text_document_identifier.rb', line 39

def to_hash
  attributes
end

#to_json(*args) ⇒ String

Parameters:

  • (Object)

Returns:

  • (String)


43
44
45
# File 'lib/language_server/protocol/interface/optional_versioned_text_document_identifier.rb', line 43

def to_json(*args)
  to_hash.to_json(*args)
end

#uriDocumentUri

The text document's uri.

Returns:

  • (DocumentUri)


33
34
35
# File 'lib/language_server/protocol/interface/optional_versioned_text_document_identifier.rb', line 33

def uri
  attributes.fetch(:uri)
end

#versioninteger | nil

The version number of this document. If a versioned text document identifier is sent from the server to the client and the file is not open in the editor (the server has not received an open notification before) the server can send null to indicate that the version is unknown and the content on disk is the truth (as specified with document content ownership).

Returns:

  • (integer | nil)


25
26
27
# File 'lib/language_server/protocol/interface/optional_versioned_text_document_identifier.rb', line 25

def version
  attributes.fetch(:version)
end