Class: LanguageServer::Protocol::Interface::ReferenceParams

Inherits:
Object
  • Object
show all
Defined in:
lib/language_server/protocol/interface/reference_params.rb

Overview

Parameters for a [ReferencesRequest](#ReferencesRequest).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(context:, text_document:, position:, work_done_token: nil, partial_result_token: nil) ⇒ ReferenceParams

Returns a new instance of ReferenceParams.



8
9
10
11
12
13
14
15
16
17
18
# File 'lib/language_server/protocol/interface/reference_params.rb', line 8

def initialize(context:, text_document:, position:, work_done_token: nil, partial_result_token: nil)
  @attributes = {}

  @attributes[:context] = context
  @attributes[:textDocument] = text_document
  @attributes[:position] = position
  @attributes[:workDoneToken] = work_done_token if work_done_token
  @attributes[:partialResultToken] = partial_result_token if partial_result_token

  @attributes.freeze
end

Instance Attribute Details

#attributesObject (readonly)

Returns the value of attribute attributes.



58
59
60
# File 'lib/language_server/protocol/interface/reference_params.rb', line 58

def attributes
  @attributes
end

Instance Method Details

#contextReferenceContext

Returns:



21
22
23
# File 'lib/language_server/protocol/interface/reference_params.rb', line 21

def context
  attributes.fetch(:context)
end

#partial_result_tokenProgressToken | nil

An optional token that a server can use to report partial results (e.g. streaming) to the client.

Returns:

  • (ProgressToken | nil)


54
55
56
# File 'lib/language_server/protocol/interface/reference_params.rb', line 54

def partial_result_token
  attributes.fetch(:partialResultToken)
end

#positionPosition

The position inside the text document.

Returns:



37
38
39
# File 'lib/language_server/protocol/interface/reference_params.rb', line 37

def position
  attributes.fetch(:position)
end

#text_documentTextDocumentIdentifier

The text document.



29
30
31
# File 'lib/language_server/protocol/interface/reference_params.rb', line 29

def text_document
  attributes.fetch(:textDocument)
end

#to_hashObject



60
61
62
# File 'lib/language_server/protocol/interface/reference_params.rb', line 60

def to_hash
  attributes
end

#to_json(*args) ⇒ Object



64
65
66
# File 'lib/language_server/protocol/interface/reference_params.rb', line 64

def to_json(*args)
  to_hash.to_json(*args)
end

#work_done_tokenProgressToken | nil

An optional token that a server can use to report work done progress.

Returns:

  • (ProgressToken | nil)


45
46
47
# File 'lib/language_server/protocol/interface/reference_params.rb', line 45

def work_done_token
  attributes.fetch(:workDoneToken)
end