Class: LanguageServer::Protocol::Interface::ReferenceRegistrationOptions

Inherits:
Object
  • Object
show all
Defined in:
lib/language_server/protocol/interface/reference_registration_options.rb

Overview

Registration options for a [ReferencesRequest](#ReferencesRequest).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(document_selector:, work_done_progress: nil) ⇒ ReferenceRegistrationOptions

Returns a new instance of ReferenceRegistrationOptions.



8
9
10
11
12
13
14
15
# File 'lib/language_server/protocol/interface/reference_registration_options.rb', line 8

def initialize(document_selector:, work_done_progress: nil)
  @attributes = {}

  @attributes[:documentSelector] = document_selector
  @attributes[:workDoneProgress] = work_done_progress if work_done_progress

  @attributes.freeze
end

Instance Attribute Details

#attributesObject (readonly)

Returns the value of attribute attributes.



31
32
33
# File 'lib/language_server/protocol/interface/reference_registration_options.rb', line 31

def attributes
  @attributes
end

Instance Method Details

#document_selectorDocumentSelector | null

A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.

Returns:

  • (DocumentSelector | null)


22
23
24
# File 'lib/language_server/protocol/interface/reference_registration_options.rb', line 22

def document_selector
  attributes.fetch(:documentSelector)
end

#to_hashObject



33
34
35
# File 'lib/language_server/protocol/interface/reference_registration_options.rb', line 33

def to_hash
  attributes
end

#to_json(*args) ⇒ Object



37
38
39
# File 'lib/language_server/protocol/interface/reference_registration_options.rb', line 37

def to_json(*args)
  to_hash.to_json(*args)
end

#work_done_progressboolean | nil

Returns:

  • (boolean | nil)


27
28
29
# File 'lib/language_server/protocol/interface/reference_registration_options.rb', line 27

def work_done_progress
  attributes.fetch(:workDoneProgress)
end