Class: LanguageServer::Protocol::Interface::SelectionRangeParams

Inherits:
Object
  • Object
show all
Defined in:
lib/language_server/protocol/interface/selection_range_params.rb,
sig/language_server/protocol/interface/selection_range_params.rbs

Overview

A parameter literal used in selection range requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(text_document:, positions:, work_done_token: nil, partial_result_token: nil) ⇒ SelectionRangeParams

Returns a new instance of SelectionRangeParams.

Parameters:

  • text_document: (Object)
  • positions: (Array[untyped])
  • work_done_token: (Object) (defaults to: nil)
  • partial_result_token: (Object) (defaults to: nil)


8
9
10
11
12
13
14
15
16
17
# File 'lib/language_server/protocol/interface/selection_range_params.rb', line 8

def initialize(text_document:, positions:, work_done_token: nil, partial_result_token: nil)
  @attributes = {}

  @attributes[:textDocument] = text_document
  @attributes[:positions] = positions
  @attributes[:workDoneToken] = work_done_token if work_done_token
  @attributes[:partialResultToken] = partial_result_token if partial_result_token

  @attributes.freeze
end

Instance Attribute Details

#attributesHash[Symbol, untyped] (readonly)

Returns the value of attribute attributes.

Returns:

  • (Hash[Symbol, untyped])


52
53
54
# File 'lib/language_server/protocol/interface/selection_range_params.rb', line 52

def attributes
  @attributes
end

Instance Method Details

#partial_result_tokenProgressToken

An optional token that a server can use to report partial results (e.g. streaming) to the client.

Returns:

  • (ProgressToken)


48
49
50
# File 'lib/language_server/protocol/interface/selection_range_params.rb', line 48

def partial_result_token
  attributes.fetch(:partialResultToken)
end

#positionsPosition[]

The positions inside the text document.

Returns:



31
32
33
# File 'lib/language_server/protocol/interface/selection_range_params.rb', line 31

def positions
  attributes.fetch(:positions)
end

#text_documentTextDocumentIdentifier

The text document.



23
24
25
# File 'lib/language_server/protocol/interface/selection_range_params.rb', line 23

def text_document
  attributes.fetch(:textDocument)
end

#to_hashHash[Symbol, untyped]

Returns:

  • (Hash[Symbol, untyped])


54
55
56
# File 'lib/language_server/protocol/interface/selection_range_params.rb', line 54

def to_hash
  attributes
end

#to_json(*args) ⇒ String

Parameters:

  • (Object)

Returns:

  • (String)


58
59
60
# File 'lib/language_server/protocol/interface/selection_range_params.rb', line 58

def to_json(*args)
  to_hash.to_json(*args)
end

#work_done_tokenProgressToken

An optional token that a server can use to report work done progress.

Returns:

  • (ProgressToken)


39
40
41
# File 'lib/language_server/protocol/interface/selection_range_params.rb', line 39

def work_done_token
  attributes.fetch(:workDoneToken)
end