Class: LanguageServer::Protocol::Interface::SemanticTokensDeltaParams

Inherits:
Object
  • Object
show all
Defined in:
lib/language_server/protocol/interface/semantic_tokens_delta_params.rb

Overview

Since:

  • 3.16.0

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(text_document:, previous_result_id:, work_done_token: nil, partial_result_token: nil) ⇒ SemanticTokensDeltaParams

Returns a new instance of SemanticTokensDeltaParams.

Since:

  • 3.16.0



8
9
10
11
12
13
14
15
16
17
# File 'lib/language_server/protocol/interface/semantic_tokens_delta_params.rb', line 8

def initialize(text_document:, previous_result_id:, work_done_token: nil, partial_result_token: nil)
  @attributes = {}

  @attributes[:textDocument] = text_document
  @attributes[:previousResultId] = previous_result_id
  @attributes[:workDoneToken] = work_done_token if work_done_token
  @attributes[:partialResultToken] = partial_result_token if partial_result_token

  @attributes.freeze
end

Instance Attribute Details

#attributesObject (readonly)

Since:

  • 3.16.0



53
54
55
# File 'lib/language_server/protocol/interface/semantic_tokens_delta_params.rb', line 53

def attributes
  @attributes
end

Instance Method Details

#partial_result_tokenProgressToken | nil

An optional token that a server can use to report partial results (e.g. streaming) to the client.

Returns:

  • (ProgressToken | nil)

Since:

  • 3.16.0



49
50
51
# File 'lib/language_server/protocol/interface/semantic_tokens_delta_params.rb', line 49

def partial_result_token
  attributes.fetch(:partialResultToken)
end

#previous_result_idstring

The result id of a previous response. The result Id can either point to a full response or a delta response depending on what was received last.

Returns:

  • (string)

Since:

  • 3.16.0



32
33
34
# File 'lib/language_server/protocol/interface/semantic_tokens_delta_params.rb', line 32

def previous_result_id
  attributes.fetch(:previousResultId)
end

#text_documentTextDocumentIdentifier

The text document.

Returns:

Since:

  • 3.16.0



23
24
25
# File 'lib/language_server/protocol/interface/semantic_tokens_delta_params.rb', line 23

def text_document
  attributes.fetch(:textDocument)
end

#to_hashObject

Since:

  • 3.16.0



55
56
57
# File 'lib/language_server/protocol/interface/semantic_tokens_delta_params.rb', line 55

def to_hash
  attributes
end

#to_json(*args) ⇒ Object

Since:

  • 3.16.0



59
60
61
# File 'lib/language_server/protocol/interface/semantic_tokens_delta_params.rb', line 59

def to_json(*args)
  to_hash.to_json(*args)
end

#work_done_tokenProgressToken | nil

An optional token that a server can use to report work done progress.

Returns:

  • (ProgressToken | nil)

Since:

  • 3.16.0



40
41
42
# File 'lib/language_server/protocol/interface/semantic_tokens_delta_params.rb', line 40

def work_done_token
  attributes.fetch(:workDoneToken)
end