Class: LanguageServer::Protocol::Interface::SemanticTokensRangeParams

Inherits:
Object
  • Object
show all
Defined in:
lib/language_server/protocol/interface/semantic_tokens_range_params.rb

Overview

Since:

  • 3.16.0

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(text_document:, range:, work_done_token: nil, partial_result_token: nil) ⇒ SemanticTokensRangeParams

Returns a new instance of SemanticTokensRangeParams.

Since:

  • 3.16.0



8
9
10
11
12
13
14
15
16
17
# File 'lib/language_server/protocol/interface/semantic_tokens_range_params.rb', line 8

def initialize(text_document:, range:, work_done_token: nil, partial_result_token: nil)
  @attributes = {}

  @attributes[:textDocument] = text_document
  @attributes[:range] = range
  @attributes[:workDoneToken] = work_done_token if work_done_token
  @attributes[:partialResultToken] = partial_result_token if partial_result_token

  @attributes.freeze
end

Instance Attribute Details

#attributesObject (readonly)

Since:

  • 3.16.0



52
53
54
# File 'lib/language_server/protocol/interface/semantic_tokens_range_params.rb', line 52

def attributes
  @attributes
end

Instance Method Details

#partial_result_tokenProgressToken | nil

An optional token that a server can use to report partial results (e.g. streaming) to the client.

Returns:

  • (ProgressToken | nil)

Since:

  • 3.16.0



48
49
50
# File 'lib/language_server/protocol/interface/semantic_tokens_range_params.rb', line 48

def partial_result_token
  attributes.fetch(:partialResultToken)
end

#rangeRange

The range the semantic tokens are requested for.

Returns:

Since:

  • 3.16.0



31
32
33
# File 'lib/language_server/protocol/interface/semantic_tokens_range_params.rb', line 31

def range
  attributes.fetch(:range)
end

#text_documentTextDocumentIdentifier

The text document.

Returns:

Since:

  • 3.16.0



23
24
25
# File 'lib/language_server/protocol/interface/semantic_tokens_range_params.rb', line 23

def text_document
  attributes.fetch(:textDocument)
end

#to_hashObject

Since:

  • 3.16.0



54
55
56
# File 'lib/language_server/protocol/interface/semantic_tokens_range_params.rb', line 54

def to_hash
  attributes
end

#to_json(*args) ⇒ Object

Since:

  • 3.16.0



58
59
60
# File 'lib/language_server/protocol/interface/semantic_tokens_range_params.rb', line 58

def to_json(*args)
  to_hash.to_json(*args)
end

#work_done_tokenProgressToken | nil

An optional token that a server can use to report work done progress.

Returns:

  • (ProgressToken | nil)

Since:

  • 3.16.0



39
40
41
# File 'lib/language_server/protocol/interface/semantic_tokens_range_params.rb', line 39

def work_done_token
  attributes.fetch(:workDoneToken)
end