Class: LanguageServer::Protocol::Interface::StaticRegistrationOptions

Inherits:
Object
  • Object
show all
Defined in:
lib/language_server/protocol/interface/static_registration_options.rb,
sig/language_server/protocol/interface/static_registration_options.rbs

Overview

Static registration options to be returned in the initialize request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil) ⇒ StaticRegistrationOptions

Returns a new instance of StaticRegistrationOptions.

Parameters:

  • id: (String) (defaults to: nil)


9
10
11
12
13
14
15
# File 'lib/language_server/protocol/interface/static_registration_options.rb', line 9

def initialize(id: nil)
  @attributes = {}

  @attributes[:id] = id if id

  @attributes.freeze
end

Instance Attribute Details

#attributesHash[Symbol, untyped] (readonly)

Returns the value of attribute attributes.

Returns:

  • (Hash[Symbol, untyped])


26
27
28
# File 'lib/language_server/protocol/interface/static_registration_options.rb', line 26

def attributes
  @attributes
end

Instance Method Details

#idstring

The id used to register the request. The id can be used to deregister the request again. See also Registration#id.

Returns:

  • (string)


22
23
24
# File 'lib/language_server/protocol/interface/static_registration_options.rb', line 22

def id
  attributes.fetch(:id)
end

#to_hashHash[Symbol, untyped]

Returns:

  • (Hash[Symbol, untyped])


28
29
30
# File 'lib/language_server/protocol/interface/static_registration_options.rb', line 28

def to_hash
  attributes
end

#to_json(*args) ⇒ String

Parameters:

  • (Object)

Returns:

  • (String)


32
33
34
# File 'lib/language_server/protocol/interface/static_registration_options.rb', line 32

def to_json(*args)
  to_hash.to_json(*args)
end