Class: LanguageServer::Protocol::Interface::TextDocumentPositionParams

Inherits:
Object
  • Object
show all
Defined in:
lib/language_server/protocol/interface/text_document_position_params.rb

Overview

A parameter literal used in requests to pass a text document and a position inside that document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(text_document:, position:) ⇒ TextDocumentPositionParams

Returns a new instance of TextDocumentPositionParams.



9
10
11
12
13
14
15
16
# File 'lib/language_server/protocol/interface/text_document_position_params.rb', line 9

def initialize(text_document:, position:)
  @attributes = {}

  @attributes[:textDocument] = text_document
  @attributes[:position] = position

  @attributes.freeze
end

Instance Attribute Details

#attributesObject (readonly)

Returns the value of attribute attributes.



34
35
36
# File 'lib/language_server/protocol/interface/text_document_position_params.rb', line 34

def attributes
  @attributes
end

Instance Method Details

#positionPosition

The position inside the text document.

Returns:



30
31
32
# File 'lib/language_server/protocol/interface/text_document_position_params.rb', line 30

def position
  attributes.fetch(:position)
end

#text_documentTextDocumentIdentifier

The text document.



22
23
24
# File 'lib/language_server/protocol/interface/text_document_position_params.rb', line 22

def text_document
  attributes.fetch(:textDocument)
end

#to_hashObject



36
37
38
# File 'lib/language_server/protocol/interface/text_document_position_params.rb', line 36

def to_hash
  attributes
end

#to_json(*args) ⇒ Object



40
41
42
# File 'lib/language_server/protocol/interface/text_document_position_params.rb', line 40

def to_json(*args)
  to_hash.to_json(*args)
end