Class: LanguageServer::Protocol::Interface::TextEdit

Inherits:
Object
  • Object
show all
Defined in:
lib/language_server/protocol/interface/text_edit.rb

Overview

A text edit applicable to a text document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(range:, new_text:) ⇒ TextEdit

Returns a new instance of TextEdit.



8
9
10
11
12
13
14
15
# File 'lib/language_server/protocol/interface/text_edit.rb', line 8

def initialize(range:, new_text:)
  @attributes = {}

  @attributes[:range] = range
  @attributes[:newText] = new_text

  @attributes.freeze
end

Instance Attribute Details

#attributesObject (readonly)

Returns the value of attribute attributes.



35
36
37
# File 'lib/language_server/protocol/interface/text_edit.rb', line 35

def attributes
  @attributes
end

Instance Method Details

#new_textstring

The string to be inserted. For delete operations use an empty string.

Returns:

  • (string)


31
32
33
# File 'lib/language_server/protocol/interface/text_edit.rb', line 31

def new_text
  attributes.fetch(:newText)
end

#rangeRange

The range of the text document to be manipulated. To insert text into a document create a range where start === end.

Returns:



22
23
24
# File 'lib/language_server/protocol/interface/text_edit.rb', line 22

def range
  attributes.fetch(:range)
end

#to_hashObject



37
38
39
# File 'lib/language_server/protocol/interface/text_edit.rb', line 37

def to_hash
  attributes
end

#to_json(*args) ⇒ Object



41
42
43
# File 'lib/language_server/protocol/interface/text_edit.rb', line 41

def to_json(*args)
  to_hash.to_json(*args)
end