Class: LanguageServer::Protocol::Interface::TypeDefinitionClientCapabilities

Inherits:
Object
  • Object
show all
Defined in:
lib/language_server/protocol/interface/type_definition_client_capabilities.rb

Overview

Since 3.6.0

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(dynamic_registration: nil, link_support: nil) ⇒ TypeDefinitionClientCapabilities

Returns a new instance of TypeDefinitionClientCapabilities.



8
9
10
11
12
13
14
15
# File 'lib/language_server/protocol/interface/type_definition_client_capabilities.rb', line 8

def initialize(dynamic_registration: nil, link_support: nil)
  @attributes = {}

  @attributes[:dynamicRegistration] = dynamic_registration if dynamic_registration
  @attributes[:linkSupport] = link_support if link_support

  @attributes.freeze
end

Instance Attribute Details

#attributesObject (readonly)

Returns the value of attribute attributes.



37
38
39
# File 'lib/language_server/protocol/interface/type_definition_client_capabilities.rb', line 37

def attributes
  @attributes
end

Instance Method Details

#dynamic_registrationboolean | nil

Whether implementation supports dynamic registration. If this is set to true the client supports the new TypeDefinitionRegistrationOptions return value for the corresponding server capability as well.

Returns:

  • (boolean | nil)


23
24
25
# File 'lib/language_server/protocol/interface/type_definition_client_capabilities.rb', line 23

def dynamic_registration
  attributes.fetch(:dynamicRegistration)
end

The client supports additional metadata in the form of definition links.

Since 3.14.0

Returns:

  • (boolean | nil)


33
34
35
# File 'lib/language_server/protocol/interface/type_definition_client_capabilities.rb', line 33

def link_support
  attributes.fetch(:linkSupport)
end

#to_hashObject



39
40
41
# File 'lib/language_server/protocol/interface/type_definition_client_capabilities.rb', line 39

def to_hash
  attributes
end

#to_json(*args) ⇒ Object



43
44
45
# File 'lib/language_server/protocol/interface/type_definition_client_capabilities.rb', line 43

def to_json(*args)
  to_hash.to_json(*args)
end