Class: LanguageServer::Protocol::Interface::WorkDoneProgressBegin
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::WorkDoneProgressBegin
- Defined in:
- lib/language_server/protocol/interface/work_done_progress_begin.rb,
sig/language_server/protocol/interface/work_done_progress_begin.rbs
Instance Attribute Summary collapse
-
#attributes ⇒ Hash[Symbol, untyped]
readonly
Returns the value of attribute attributes.
Instance Method Summary collapse
-
#cancellable ⇒ boolean
Controls if a cancel button should show to allow the user to cancel the long running operation.
-
#initialize(kind:, title:, cancellable: nil, message: nil, percentage: nil) ⇒ WorkDoneProgressBegin
constructor
A new instance of WorkDoneProgressBegin.
- #kind ⇒ "begin"
-
#message ⇒ string
Optional, more detailed associated progress message.
-
#percentage ⇒ uinteger
Optional progress percentage to display (value 100 is considered 100%).
-
#title ⇒ string
Mandatory title of the progress operation.
- #to_hash ⇒ Hash[Symbol, untyped]
- #to_json(*args) ⇒ String
Constructor Details
#initialize(kind:, title:, cancellable: nil, message: nil, percentage: nil) ⇒ WorkDoneProgressBegin
Returns a new instance of WorkDoneProgressBegin.
5 6 7 8 9 10 11 12 13 14 15 |
# File 'lib/language_server/protocol/interface/work_done_progress_begin.rb', line 5 def initialize(kind:, title:, cancellable: nil, message: nil, percentage: nil) @attributes = {} @attributes[:kind] = kind @attributes[:title] = title @attributes[:cancellable] = cancellable if cancellable @attributes[:message] = if @attributes[:percentage] = percentage if percentage @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Hash[Symbol, untyped] (readonly)
Returns the value of attribute attributes.
68 69 70 |
# File 'lib/language_server/protocol/interface/work_done_progress_begin.rb', line 68 def attributes @attributes end |
Instance Method Details
#cancellable ⇒ boolean
Controls if a cancel button should show to allow the user to cancel the long running operation. Clients that don't support cancellation are allowed to ignore the setting.
39 40 41 |
# File 'lib/language_server/protocol/interface/work_done_progress_begin.rb', line 39 def cancellable attributes.fetch(:cancellable) end |
#kind ⇒ "begin"
18 19 20 |
# File 'lib/language_server/protocol/interface/work_done_progress_begin.rb', line 18 def kind attributes.fetch(:kind) end |
#message ⇒ string
Optional, more detailed associated progress message. Contains
complementary information to the title.
Examples: "3/25 files", "project/src/module2", "node_modules/some_dep". If unset, the previous progress message (if any) is still valid.
51 52 53 |
# File 'lib/language_server/protocol/interface/work_done_progress_begin.rb', line 51 def attributes.fetch(:message) end |
#percentage ⇒ uinteger
Optional progress percentage to display (value 100 is considered 100%).
If not provided infinite progress is assumed and clients are allowed
to ignore the percentage value in subsequent in report notifications.
The value should be steadily rising. Clients are free to ignore values that are not following this rule. The value range is [0, 100].
64 65 66 |
# File 'lib/language_server/protocol/interface/work_done_progress_begin.rb', line 64 def percentage attributes.fetch(:percentage) end |
#title ⇒ string
Mandatory title of the progress operation. Used to briefly inform about the kind of operation being performed.
Examples: "Indexing" or "Linking dependencies".
29 30 31 |
# File 'lib/language_server/protocol/interface/work_done_progress_begin.rb', line 29 def title attributes.fetch(:title) end |
#to_hash ⇒ Hash[Symbol, untyped]
70 71 72 |
# File 'lib/language_server/protocol/interface/work_done_progress_begin.rb', line 70 def to_hash attributes end |
#to_json(*args) ⇒ String
74 75 76 |
# File 'lib/language_server/protocol/interface/work_done_progress_begin.rb', line 74 def to_json(*args) to_hash.to_json(*args) end |