Class: LanguageServer::Protocol::Interface::WorkspaceEdit
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::WorkspaceEdit
- Defined in:
- lib/language_server/protocol/interface/workspace_edit.rb,
sig/language_server/protocol/interface/workspace_edit.rbs
Overview
A workspace edit represents changes to many resources managed in the workspace. The edit
should either provide changes or documentChanges. If documentChanges are present
they are preferred over changes if the client can handle versioned document edits.
Since version 3.13.0 a workspace edit can contain resource operations as well. If resource operations are present clients need to execute the operations in the order in which they are provided. So a workspace edit for example can consist of the following two changes: (1) a create file a.txt and (2) a text document edit which insert text into file a.txt.
An invalid sequence (e.g. (1) delete file a.txt and (2) insert text into file a.txt) will
cause failure of the operation. How the client recovers from the failure is described by
the client capability: workspace.workspaceEdit.failureHandling
Instance Attribute Summary collapse
-
#attributes ⇒ Hash[Symbol, untyped]
readonly
Returns the value of attribute attributes.
Instance Method Summary collapse
-
#change_annotations ⇒ ChangeAnnotationIdentifier => ChangeAnnotation
A map of change annotations that can be referenced in
AnnotatedTextEdits or create, rename and delete file / folder operations. -
#changes ⇒ DocumentUri => TextEdit[]
Holds changes to existing resources.
-
#document_changes ⇒ TextDocumentEdit | CreateFile | RenameFile | DeleteFile[]
Depending on the client capability
workspace.workspaceEdit.resourceOperationsdocument changes are either an array ofTextDocumentEdits to express changes to n different text documents where each text document edit addresses a specific version of a text document. -
#initialize(changes: nil, document_changes: nil, change_annotations: nil) ⇒ WorkspaceEdit
constructor
A new instance of WorkspaceEdit.
- #to_hash ⇒ Hash[Symbol, untyped]
- #to_json(*args) ⇒ String
Constructor Details
#initialize(changes: nil, document_changes: nil, change_annotations: nil) ⇒ WorkspaceEdit
Returns a new instance of WorkspaceEdit.
19 20 21 22 23 24 25 26 27 |
# File 'lib/language_server/protocol/interface/workspace_edit.rb', line 19 def initialize(changes: nil, document_changes: nil, change_annotations: nil) @attributes = {} @attributes[:changes] = changes if changes @attributes[:documentChanges] = document_changes if document_changes @attributes[:changeAnnotations] = change_annotations if change_annotations @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Hash[Symbol, untyped] (readonly)
Returns the value of attribute attributes.
67 68 69 |
# File 'lib/language_server/protocol/interface/workspace_edit.rb', line 67 def attributes @attributes end |
Instance Method Details
#change_annotations ⇒ ChangeAnnotationIdentifier => ChangeAnnotation
A map of change annotations that can be referenced in AnnotatedTextEdits or create, rename and
delete file / folder operations.
Whether clients honor this property depends on the client capability workspace.changeAnnotationSupport.
63 64 65 |
# File 'lib/language_server/protocol/interface/workspace_edit.rb', line 63 def change_annotations attributes.fetch(:changeAnnotations) end |
#changes ⇒ DocumentUri => TextEdit[]
Holds changes to existing resources.
33 34 35 |
# File 'lib/language_server/protocol/interface/workspace_edit.rb', line 33 def changes attributes.fetch(:changes) end |
#document_changes ⇒ TextDocumentEdit | CreateFile | RenameFile | DeleteFile[]
Depending on the client capability workspace.workspaceEdit.resourceOperations document changes
are either an array of TextDocumentEdits to express changes to n different text documents
where each text document edit addresses a specific version of a text document. Or it can contain
above TextDocumentEdits mixed with create, rename and delete file / folder operations.
Whether a client supports versioned document edits is expressed via
workspace.workspaceEdit.documentChanges client capability.
If a client neither supports documentChanges nor workspace.workspaceEdit.resourceOperations then
only plain TextEdits using the changes property are supported.
50 51 52 |
# File 'lib/language_server/protocol/interface/workspace_edit.rb', line 50 def document_changes attributes.fetch(:documentChanges) end |
#to_hash ⇒ Hash[Symbol, untyped]
69 70 71 |
# File 'lib/language_server/protocol/interface/workspace_edit.rb', line 69 def to_hash attributes end |
#to_json(*args) ⇒ String
73 74 75 |
# File 'lib/language_server/protocol/interface/workspace_edit.rb', line 73 def to_json(*args) to_hash.to_json(*args) end |