Class: LanguageServer::Protocol::Interface::WorkspaceSymbolOptions
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::WorkspaceSymbolOptions
- Defined in:
- lib/language_server/protocol/interface/workspace_symbol_options.rb
Overview
Server capabilities for a [WorkspaceSymbolRequest](#WorkspaceSymbolRequest).
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
Instance Method Summary collapse
-
#initialize(resolve_provider: nil, work_done_progress: nil) ⇒ WorkspaceSymbolOptions
constructor
A new instance of WorkspaceSymbolOptions.
-
#resolve_provider ⇒ boolean | nil
The server provides support to resolve additional information for a workspace symbol.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
- #work_done_progress ⇒ boolean | nil
Constructor Details
#initialize(resolve_provider: nil, work_done_progress: nil) ⇒ WorkspaceSymbolOptions
Returns a new instance of WorkspaceSymbolOptions.
8 9 10 11 12 13 14 15 |
# File 'lib/language_server/protocol/interface/workspace_symbol_options.rb', line 8 def initialize(resolve_provider: nil, work_done_progress: nil) @attributes = {} @attributes[:resolveProvider] = resolve_provider if resolve_provider @attributes[:workDoneProgress] = work_done_progress if work_done_progress @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
33 34 35 |
# File 'lib/language_server/protocol/interface/workspace_symbol_options.rb', line 33 def attributes @attributes end |
Instance Method Details
#resolve_provider ⇒ boolean | nil
The server provides support to resolve additional information for a workspace symbol.
24 25 26 |
# File 'lib/language_server/protocol/interface/workspace_symbol_options.rb', line 24 def resolve_provider attributes.fetch(:resolveProvider) end |
#to_hash ⇒ Object
35 36 37 |
# File 'lib/language_server/protocol/interface/workspace_symbol_options.rb', line 35 def to_hash attributes end |
#to_json(*args) ⇒ Object
39 40 41 |
# File 'lib/language_server/protocol/interface/workspace_symbol_options.rb', line 39 def to_json(*args) to_hash.to_json(*args) end |
#work_done_progress ⇒ boolean | nil
29 30 31 |
# File 'lib/language_server/protocol/interface/workspace_symbol_options.rb', line 29 def work_done_progress attributes.fetch(:workDoneProgress) end |