Class: LanguageServer::Protocol::Interface::WorkspaceUnchangedDocumentDiagnosticReport
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::WorkspaceUnchangedDocumentDiagnosticReport
- Defined in:
- lib/language_server/protocol/interface/workspace_unchanged_document_diagnostic_report.rb
Overview
An unchanged document diagnostic report for a workspace diagnostic result.
Instance Attribute Summary collapse
- #attributes ⇒ Object readonly
Instance Method Summary collapse
-
#initialize(uri:, version:, kind:, result_id:) ⇒ WorkspaceUnchangedDocumentDiagnosticReport
constructor
A new instance of WorkspaceUnchangedDocumentDiagnosticReport.
-
#kind ⇒ "unchanged"
A document diagnostic report indicating no changes to the last result.
-
#result_id ⇒ string
A result id which will be sent on the next diagnostic request for the same document.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
-
#uri ⇒ DocumentUri
The URI for which diagnostic information is reported.
-
#version ⇒ integer | null
The version number for which the diagnostics are reported.
Constructor Details
#initialize(uri:, version:, kind:, result_id:) ⇒ WorkspaceUnchangedDocumentDiagnosticReport
Returns a new instance of WorkspaceUnchangedDocumentDiagnosticReport.
10 11 12 13 14 15 16 17 18 19 |
# File 'lib/language_server/protocol/interface/workspace_unchanged_document_diagnostic_report.rb', line 10 def initialize(uri:, version:, kind:, result_id:) @attributes = {} @attributes[:uri] = uri @attributes[:version] = version @attributes[:kind] = kind @attributes[:resultId] = result_id @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
58 59 60 |
# File 'lib/language_server/protocol/interface/workspace_unchanged_document_diagnostic_report.rb', line 58 def attributes @attributes end |
Instance Method Details
#kind ⇒ "unchanged"
A document diagnostic report indicating no changes to the last result. A server can only return unchanged if result ids are provided.
45 46 47 |
# File 'lib/language_server/protocol/interface/workspace_unchanged_document_diagnostic_report.rb', line 45 def kind attributes.fetch(:kind) end |
#result_id ⇒ string
A result id which will be sent on the next diagnostic request for the same document.
54 55 56 |
# File 'lib/language_server/protocol/interface/workspace_unchanged_document_diagnostic_report.rb', line 54 def result_id attributes.fetch(:resultId) end |
#to_hash ⇒ Object
60 61 62 |
# File 'lib/language_server/protocol/interface/workspace_unchanged_document_diagnostic_report.rb', line 60 def to_hash attributes end |
#to_json(*args) ⇒ Object
64 65 66 |
# File 'lib/language_server/protocol/interface/workspace_unchanged_document_diagnostic_report.rb', line 64 def to_json(*args) to_hash.to_json(*args) end |
#uri ⇒ DocumentUri
The URI for which diagnostic information is reported.
25 26 27 |
# File 'lib/language_server/protocol/interface/workspace_unchanged_document_diagnostic_report.rb', line 25 def uri attributes.fetch(:uri) end |
#version ⇒ integer | null
The version number for which the diagnostics are reported. If the document is not marked as open null can be provided.
34 35 36 |
# File 'lib/language_server/protocol/interface/workspace_unchanged_document_diagnostic_report.rb', line 34 def version attributes.fetch(:version) end |