Module: LanguageServer::Protocol::Constant::CodeActionKind
- Defined in:
- lib/language_server/protocol/constant/code_action_kind.rb
Overview
A set of predefined code action kinds
Constant Summary collapse
- EMPTY =
Empty kind.
""- QUICK_FIX =
Base kind for quickfix actions: ‘quickfix’
"quickfix"- REFACTOR =
Base kind for refactoring actions: ‘refactor’
"refactor"- REFACTOR_EXTRACT =
Base kind for refactoring extraction actions: ‘refactor.extract’
Example extract actions:
-
Extract method
-
Extract function
-
Extract variable
-
Extract interface from class
-
…
-
"refactor.extract"- REFACTOR_INLINE =
Base kind for refactoring inline actions: ‘refactor.inline’
Example inline actions:
-
Inline function
-
Inline variable
-
Inline constant
-
…
-
"refactor.inline"- REFACTOR_REWRITE =
Base kind for refactoring rewrite actions: ‘refactor.rewrite’
Example rewrite actions:
-
Convert JavaScript function to class
-
Add or remove parameter
-
Encapsulate field
-
Make method static
-
Move method to base class
-
…
-
"refactor.rewrite"- SOURCE =
Base kind for source actions:
sourceSource code actions apply to the entire file.
"source"- SOURCE_ORGANIZE_IMPORTS =
Base kind for an organize imports source action:
source.organizeImports "source.organizeImports"- SOURCE_FIX_ALL =
Base kind for auto-fix source actions:
source.fixAll.Fix all actions automatically fix errors that have a clear fix that do not require user input. They should not suppress errors or perform unsafe fixes such as generating new types or classes.
"source.fixAll"