Module: LanguageServer::Protocol::Constant::CodeActionKind
- Defined in:
- lib/language_server/protocol/constant/code_action_kind.rb
Overview
The kind of a code action.
Kinds are a hierarchical list of identifiers separated by ., e.g. ‘“refactor.extract.function”`.
The set of kinds is open and client needs to announce the kinds it supports to the server during initialization. A set of predefined code action kinds
Constant Summary collapse
- QUICK_FIX =
Base kind for quickfix actions: ‘quickfix’
'quickfix'- REFACTOR =
Base kind for refactoring actions: ‘refactor’
'refactor'- REFACTOR_EXTRACT =
Base kind for refactoring extraction actions: ‘refactor.extract’
Example extract actions:
-
Extract method
-
Extract function
-
Extract variable
-
Extract interface from class
-
…
-
'refactor.extract'- REFACTOR_INLINE =
Base kind for refactoring inline actions: ‘refactor.inline’
Example inline actions:
-
Inline function
-
Inline variable
-
Inline constant
-
…
-
'refactor.inline'- REFACTOR_REWRITE =
Base kind for refactoring rewrite actions: ‘refactor.rewrite’
Example rewrite actions:
-
Convert JavaScript function to class
-
Add or remove parameter
-
Encapsulate field
-
Make method static
-
Move method to base class
-
…
-
'refactor.rewrite'- SOURCE =
Base kind for source actions:
sourceSource code actions apply to the entire file.
'source'- SOURCE_ORGANIZE_IMPORTS =
Base kind for an organize imports source action:
source.organizeImports 'source.organizeImports'