Module: LanguageServer::Protocol::Constant::DiagnosticTag

Defined in:
lib/language_server/protocol/constant/diagnostic_tag.rb

Overview

The diagnostic tags.

Since:

  • 3.15.0

Constant Summary collapse

UNNECESSARY =

Unused or unnecessary code.

Clients are allowed to render diagnostics with this tag faded out instead of having an error squiggle.

Since:

  • 3.15.0

1
DEPRECATED =

Deprecated or obsolete code.

Clients are allowed to rendered diagnostics with this tag strike through.

Since:

  • 3.15.0

2