Module: LanguageServer::Protocol::Constant::MonikerKind

Defined in:
lib/language_server/protocol/constant/moniker_kind.rb

Overview

The moniker kind.

Since:

  • 3.16.0

Constant Summary collapse

IMPORT =

The moniker represent a symbol that is imported into a project

Since:

  • 3.16.0

"import"
EXPORT =

The moniker represents a symbol that is exported from a project

Since:

  • 3.16.0

"export"
LOCAL =

The moniker represents a symbol that is local to a project (e.g. a local variable of a function, a class not visible outside the project, …)

Since:

  • 3.16.0

"local"