Module: LanguageServer::Protocol::Constant::PositionEncodingKind
- Defined in:
- lib/language_server/protocol/constant/position_encoding_kind.rb
Overview
A set of predefined position encoding kinds.
Constant Summary collapse
- UTF8 =
Character offsets count UTF-8 code units.
"utf-8"- UTF16 =
Character offsets count UTF-16 code units.
This is the default and must always be supported by servers
"utf-16"- UTF32 =
Character offsets count UTF-32 code units.
Implementation note: these are the same as Unicode code points, so this
PositionEncodingKindmay also be used for an encoding-agnostic representation of character offsets. "utf-32"