Module: LanguageServer::Protocol::Constant::SemanticTokenModifiers
- Defined in:
- lib/language_server/protocol/constant/semantic_token_modifiers.rb
Overview
A set of predefined token modifiers. This set is not fixed an clients can specify additional token types via the corresponding client capabilities.
Constant Summary collapse
- DECLARATION =
"declaration"- DEFINITION =
"definition"- READONLY =
"readonly"- STATIC =
"static"- DEPRECATED =
"deprecated"- ABSTRACT =
"abstract"- ASYNC =
"async"- MODIFICATION =
"modification"- DOCUMENTATION =
"documentation"- DEFAULT_LIBRARY =
"defaultLibrary"