Module: LanguageServer::Protocol::Constant::SemanticTokenTypes
- Defined in:
- lib/language_server/protocol/constant/semantic_token_types.rb
Overview
A set of predefined token types. This set is not fixed an clients can specify additional token types via the corresponding client capabilities.
Constant Summary collapse
- NAMESPACE =
"namespace"- TYPE =
Represents a generic type. Acts as a fallback for types which can’t be mapped to a specific type like class or enum.
"type"- CLASS =
"class"- ENUM =
"enum"- INTERFACE =
"interface"- STRUCT =
"struct"- TYPE_PARAMETER =
"typeParameter"- PARAMETER =
"parameter"- VARIABLE =
"variable"- PROPERTY =
"property"- ENUM_MEMBER =
"enumMember"- EVENT =
"event"- FUNCTION =
"function"- METHOD =
"method"- MACRO =
"macro"- KEYWORD =
"keyword"- MODIFIER =
"modifier"- COMMENT =
"comment"- STRING =
"string"- NUMBER =
"number"- REGEXP =
"regexp"- OPERATOR =
"operator"- DECORATOR =
"decorator"