Module: LanguageServer::Protocol::Constant::SymbolTag

Defined in:
lib/language_server/protocol/constant/symbol_tag.rb

Overview

Symbol tags are extra annotations that tweak the rendering of a symbol.

Since:

  • 3.16

Constant Summary collapse

DEPRECATED =

Render a symbol as obsolete, usually using a strike-out.

Since:

  • 3.16

1