Module: LanguageServer::Protocol::Constant::UniquenessLevel

Defined in:
lib/language_server/protocol/constant/uniqueness_level.rb

Overview

Moniker uniqueness level to define scope of the moniker.

Since:

  • 3.16.0

Constant Summary collapse

DOCUMENT =

The moniker is only unique inside a document

Since:

  • 3.16.0

"document"
PROJECT =

The moniker is unique inside a project for which a dump got created

Since:

  • 3.16.0

"project"
GROUP =

The moniker is unique inside the group to which a project belongs

Since:

  • 3.16.0

"group"
SCHEME =

The moniker is unique inside the moniker scheme.

Since:

  • 3.16.0

"scheme"
GLOBAL =

The moniker is globally unique

Since:

  • 3.16.0

"global"