Class: LanguageServer::Protocol::Interface::CodeDescription
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::CodeDescription
- Defined in:
- lib/language_server/protocol/interface/code_description.rb
Overview
Structure to capture a description for an error code.
Instance Attribute Summary collapse
- #attributes ⇒ Object readonly
Instance Method Summary collapse
-
#href ⇒ URI
An URI to open with more information about the diagnostic error.
-
#initialize(href:) ⇒ CodeDescription
constructor
A new instance of CodeDescription.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
Constructor Details
#initialize(href:) ⇒ CodeDescription
Returns a new instance of CodeDescription.
10 11 12 13 14 15 16 |
# File 'lib/language_server/protocol/interface/code_description.rb', line 10 def initialize(href:) @attributes = {} @attributes[:href] = href @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
26 27 28 |
# File 'lib/language_server/protocol/interface/code_description.rb', line 26 def attributes @attributes end |
Instance Method Details
#href ⇒ URI
An URI to open with more information about the diagnostic error.
22 23 24 |
# File 'lib/language_server/protocol/interface/code_description.rb', line 22 def href attributes.fetch(:href) end |
#to_hash ⇒ Object
28 29 30 |
# File 'lib/language_server/protocol/interface/code_description.rb', line 28 def to_hash attributes end |
#to_json(*args) ⇒ Object
32 33 34 |
# File 'lib/language_server/protocol/interface/code_description.rb', line 32 def to_json(*args) to_hash.to_json(*args) end |