Class: LanguageServer::Protocol::Interface::CompletionItem
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::CompletionItem
- Defined in:
- lib/language_server/protocol/interface/completion_item.rb
Overview
A completion item represents a text snippet that is proposed to complete text that is being typed.
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
Instance Method Summary collapse
-
#additional_text_edits ⇒ TextEdit[] | nil
An optional array of additional [text edits](#TextEdit) that are applied when selecting this completion.
-
#command ⇒ Command | nil
An optional [command](#Command) that is executed after inserting this completion.
-
#commit_characters ⇒ string[] | nil
An optional set of characters that when pressed while this completion is active will accept it first and then type that character.
-
#data ⇒ LSPAny | nil
A data entry field that is preserved on a completion item between a [CompletionRequest](#CompletionRequest) and a [CompletionResolveRequest](#CompletionResolveRequest).
-
#deprecated ⇒ boolean | nil
deprecated
Deprecated.
Use
tagsinstead. -
#detail ⇒ string | nil
A human-readable string with additional information about this item, like type or symbol information.
-
#documentation ⇒ string | MarkupContent | nil
A human-readable string that represents a doc-comment.
-
#filter_text ⇒ string | nil
A string that should be used when filtering a set of completion items.
-
#initialize(label:, label_details: nil, kind: nil, tags: nil, detail: nil, documentation: nil, deprecated: nil, preselect: nil, sort_text: nil, filter_text: nil, insert_text: nil, insert_text_format: nil, insert_text_mode: nil, text_edit: nil, text_edit_text: nil, additional_text_edits: nil, commit_characters: nil, command: nil, data: nil) ⇒ CompletionItem
constructor
A new instance of CompletionItem.
-
#insert_text ⇒ string | nil
A string that should be inserted into a document when selecting this completion.
-
#insert_text_format ⇒ InsertTextFormat | nil
The format of the insert text.
-
#insert_text_mode ⇒ InsertTextMode | nil
How whitespace and indentation is handled during completion item insertion.
-
#kind ⇒ CompletionItemKind | nil
The kind of this completion item.
-
#label ⇒ string
The label of this completion item.
-
#label_details ⇒ CompletionItemLabelDetails | nil
Additional details for the label.
-
#preselect ⇒ boolean | nil
Select this item when showing.
-
#sort_text ⇒ string | nil
A string that should be used when comparing this item with other items.
-
#tags ⇒ CompletionItemTag[] | nil
Tags for this completion item.
-
#text_edit ⇒ TextEdit | InsertReplaceEdit | nil
An [edit](#TextEdit) which is applied to a document when selecting this completion.
-
#text_edit_text ⇒ string | nil
The edit text used if the completion item is part of a CompletionList and CompletionList defines an item default for the text edit range.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
Constructor Details
#initialize(label:, label_details: nil, kind: nil, tags: nil, detail: nil, documentation: nil, deprecated: nil, preselect: nil, sort_text: nil, filter_text: nil, insert_text: nil, insert_text_format: nil, insert_text_mode: nil, text_edit: nil, text_edit_text: nil, additional_text_edits: nil, commit_characters: nil, command: nil, data: nil) ⇒ CompletionItem
Returns a new instance of CompletionItem.
9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 9 def initialize(label:, label_details: nil, kind: nil, tags: nil, detail: nil, documentation: nil, deprecated: nil, preselect: nil, sort_text: nil, filter_text: nil, insert_text: nil, insert_text_format: nil, insert_text_mode: nil, text_edit: nil, text_edit_text: nil, additional_text_edits: nil, commit_characters: nil, command: nil, data: nil) @attributes = {} @attributes[:label] = label @attributes[:labelDetails] = label_details if label_details @attributes[:kind] = kind if kind @attributes[:tags] = if @attributes[:detail] = detail if detail @attributes[:documentation] = documentation if documentation @attributes[:deprecated] = deprecated if deprecated @attributes[:preselect] = preselect if preselect @attributes[:sortText] = sort_text if sort_text @attributes[:filterText] = filter_text if filter_text @attributes[:insertText] = insert_text if insert_text @attributes[:insertTextFormat] = insert_text_format if insert_text_format @attributes[:insertTextMode] = insert_text_mode if insert_text_mode @attributes[:textEdit] = text_edit if text_edit @attributes[:textEditText] = text_edit_text if text_edit_text @attributes[:additionalTextEdits] = additional_text_edits if additional_text_edits @attributes[:commitCharacters] = commit_characters if commit_characters @attributes[:command] = command if command @attributes[:data] = data if data @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
266 267 268 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 266 def attributes @attributes end |
Instance Method Details
#additional_text_edits ⇒ TextEdit[] | nil
An optional array of additional [text edits](#TextEdit) that are applied when selecting this completion. Edits must not overlap (including the same insert position) with the main [edit](#CompletionItem.textEdit) nor with themselves.
Additional text edits should be used to change text unrelated to the current cursor position (for example adding an import statement at the top of the file if the completion item will insert an unqualified type).
233 234 235 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 233 def additional_text_edits attributes.fetch(:additionalTextEdits) end |
#command ⇒ Command | nil
An optional [command](#Command) that is executed after inserting this completion. Note that additional modifications to the current document should be described with the [additionalTextEdits](#CompletionItem.additionalTextEdits)-property.
253 254 255 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 253 def command attributes.fetch(:command) end |
#commit_characters ⇒ string[] | nil
An optional set of characters that when pressed while this completion is active will accept it first and then type that character. Note that all commit characters should have ‘length=1` and that superfluous characters will be ignored.
243 244 245 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 243 def commit_characters attributes.fetch(:commitCharacters) end |
#data ⇒ LSPAny | nil
A data entry field that is preserved on a completion item between a [CompletionRequest](#CompletionRequest) and a [CompletionResolveRequest](#CompletionResolveRequest).
262 263 264 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 262 def data attributes.fetch(:data) end |
#deprecated ⇒ boolean | nil
Use tags instead.
Indicates if this item is deprecated.
100 101 102 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 100 def deprecated attributes.fetch(:deprecated) end |
#detail ⇒ string | nil
A human-readable string with additional information about this item, like type or symbol information.
83 84 85 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 83 def detail attributes.fetch(:detail) end |
#documentation ⇒ string | MarkupContent | nil
A human-readable string that represents a doc-comment.
91 92 93 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 91 def documentation attributes.fetch(:documentation) end |
#filter_text ⇒ string | nil
A string that should be used when filtering a set of completion items. When falsy the [label](#CompletionItem.label) is used.
132 133 134 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 132 def filter_text attributes.fetch(:filterText) end |
#insert_text ⇒ string | nil
A string that should be inserted into a document when selecting this completion. When falsy the [label](#CompletionItem.label) is used.
The insertText is subject to interpretation by the client side. Some tools might not take the string literally. For example VS Code when code complete is requested in this example ‘con<cursor position>` and a completion item with an insertText of console is provided it will only insert sole. Therefore it is recommended to use textEdit instead since it avoids additional client side interpretation.
150 151 152 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 150 def insert_text attributes.fetch(:insertText) end |
#insert_text_format ⇒ InsertTextFormat | nil
The format of the insert text. The format applies to both the insertText property and the newText property of a provided textEdit. If omitted defaults to InsertTextFormat.PlainText.
Please note that the insertTextFormat doesn’t apply to additionalTextEdits.
163 164 165 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 163 def insert_text_format attributes.fetch(:insertTextFormat) end |
#insert_text_mode ⇒ InsertTextMode | nil
How whitespace and indentation is handled during completion item insertion. If not provided the clients default value depends on the textDocument.completion.insertTextMode client capability.
175 176 177 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 175 def insert_text_mode attributes.fetch(:insertTextMode) end |
#kind ⇒ CompletionItemKind | nil
The kind of this completion item. Based of the kind an icon is chosen by the editor.
64 65 66 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 64 def kind attributes.fetch(:kind) end |
#label ⇒ string
The label of this completion item.
The label property is also by default the text that is inserted when selecting this completion.
If label details are provided the label itself should be an unqualified name of the completion item.
45 46 47 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 45 def label attributes.fetch(:label) end |
#label_details ⇒ CompletionItemLabelDetails | nil
Additional details for the label
55 56 57 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 55 def label_details attributes.fetch(:labelDetails) end |
#preselect ⇒ boolean | nil
Select this item when showing.
Note that only one completion item can be selected and that the tool / client decides which item that is. The rule is that the first item of those that match best is selected.
112 113 114 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 112 def preselect attributes.fetch(:preselect) end |
#sort_text ⇒ string | nil
A string that should be used when comparing this item with other items. When falsy the [label](#CompletionItem.label) is used.
122 123 124 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 122 def sort_text attributes.fetch(:sortText) end |
#tags ⇒ CompletionItemTag[] | nil
Tags for this completion item.
74 75 76 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 74 def attributes.fetch(:tags) end |
#text_edit ⇒ TextEdit | InsertReplaceEdit | nil
An [edit](#TextEdit) which is applied to a document when selecting this completion. When an edit is provided the value of [insertText](#CompletionItem.insertText) is ignored.
Most editors support two different operations when accepting a completion item. One is to insert a completion text and the other is to replace an existing text with a completion text. Since this can usually not be predetermined by a server it can report both ranges. Clients need to signal support for InsertReplaceEdits via the textDocument.completion.insertReplaceSupport client capability property.
*Note 1:* The text edit’s range as well as both ranges from an insert replace edit must be a [single line] and they must contain the position at which completion has been requested. *Note 2:* If an InsertReplaceEdit is returned the edit’s insert range must be a prefix of the edit’s replace range, that means it must be contained and starting at the same position.
202 203 204 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 202 def text_edit attributes.fetch(:textEdit) end |
#text_edit_text ⇒ string | nil
The edit text used if the completion item is part of a CompletionList and CompletionList defines an item default for the text edit range.
Clients will only honor this property if they opt into completion list item defaults using the capability completionList.itemDefaults.
If not provided and a list’s default range is provided the label property is used as a text.
219 220 221 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 219 def text_edit_text attributes.fetch(:textEditText) end |
#to_hash ⇒ Object
268 269 270 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 268 def to_hash attributes end |
#to_json(*args) ⇒ Object
272 273 274 |
# File 'lib/language_server/protocol/interface/completion_item.rb', line 272 def to_json(*args) to_hash.to_json(*args) end |