Class: LanguageServer::Protocol::Interface::CompletionItem

Inherits:
Object
  • Object
show all
Defined in:
lib/language_server/protocol/interface/completion_item.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(label:, kind: nil, detail: nil, documentation: nil, deprecated: nil, sort_text: nil, filter_text: nil, insert_text: nil, insert_text_format: nil, text_edit: nil, additional_text_edits: nil, commit_characters: nil, command: nil, data: nil) ⇒ CompletionItem

Returns a new instance of CompletionItem.



5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
# File 'lib/language_server/protocol/interface/completion_item.rb', line 5

def initialize(label:, kind: nil, detail: nil, documentation: nil, deprecated: nil, sort_text: nil, filter_text: nil, insert_text: nil, insert_text_format: nil, text_edit: nil, additional_text_edits: nil, commit_characters: nil, command: nil, data: nil)
  @attributes = {}

  @attributes[:label] = label
  @attributes[:kind] = kind if kind
  @attributes[:detail] = detail if detail
  @attributes[:documentation] = documentation if documentation
  @attributes[:deprecated] = deprecated if deprecated
  @attributes[:sortText] = sort_text if sort_text
  @attributes[:filterText] = filter_text if filter_text
  @attributes[:insertText] = insert_text if insert_text
  @attributes[:insertTextFormat] = insert_text_format if insert_text_format
  @attributes[:textEdit] = text_edit if text_edit
  @attributes[:additionalTextEdits] = additional_text_edits if additional_text_edits
  @attributes[:commitCharacters] = commit_characters if commit_characters
  @attributes[:command] = command if command
  @attributes[:data] = data if data

  @attributes.freeze
end

Instance Attribute Details

#attributesObject (readonly)

Returns the value of attribute attributes.



168
169
170
# File 'lib/language_server/protocol/interface/completion_item.rb', line 168

def attributes
  @attributes
end

Instance Method Details

#additional_text_editsTextEdit[]

An optional array of additional text edits that are applied when selecting this completion. Edits must not overlap (including the same insert position) with the main edit nor with themselves.

Additional text edits should be used to change text unrelated to the current cursor position (for example adding an import statement at the top of the file if the completion item will insert an unqualified type).

Returns:



135
136
137
# File 'lib/language_server/protocol/interface/completion_item.rb', line 135

def additional_text_edits
  attributes.fetch(:additionalTextEdits)
end

#commandCommand

An optional command that is executed after inserting this completion. Note that additional modifications to the current document should be described with the additionalTextEdits-property.

Returns:



155
156
157
# File 'lib/language_server/protocol/interface/completion_item.rb', line 155

def command
  attributes.fetch(:command)
end

#commit_charactersstring[]

An optional set of characters that when pressed while this completion is active will accept it first and then type that character. Note that all commit characters should have ‘length=1` and that superfluous characters will be ignored.

Returns:

  • (string[])


145
146
147
# File 'lib/language_server/protocol/interface/completion_item.rb', line 145

def commit_characters
  attributes.fetch(:commitCharacters)
end

#dataany

An data entry field that is preserved on a completion item between a completion and a completion resolve request.

Returns:

  • (any)


164
165
166
# File 'lib/language_server/protocol/interface/completion_item.rb', line 164

def data
  attributes.fetch(:data)
end

#deprecatedboolean

Indicates if this item is deprecated.

Returns:

  • (boolean)


66
67
68
# File 'lib/language_server/protocol/interface/completion_item.rb', line 66

def deprecated
  attributes.fetch(:deprecated)
end

#detailstring

A human-readable string with additional information about this item, like type or symbol information.

Returns:

  • (string)


50
51
52
# File 'lib/language_server/protocol/interface/completion_item.rb', line 50

def detail
  attributes.fetch(:detail)
end

#documentationstring | MarkupContent

A human-readable string that represents a doc-comment.

Returns:



58
59
60
# File 'lib/language_server/protocol/interface/completion_item.rb', line 58

def documentation
  attributes.fetch(:documentation)
end

#filter_textstring

A string that should be used when filtering a set of completion items. When falsy the label is used.

Returns:

  • (string)


84
85
86
# File 'lib/language_server/protocol/interface/completion_item.rb', line 84

def filter_text
  attributes.fetch(:filterText)
end

#insert_textstring

A string that should be inserted into a document when selecting this completion. When falsy the label is used.

The insertText is subject to interpretation by the client side. Some tools might not take the string literally. For example VS Code when code complete is requested in this example ‘con<cursor position>` and a completion item with an insertText of console is provided it will only insert sole. Therefore it is recommended to use textEdit instead since it avoids additional client side interpretation.

Returns:

  • (string)


100
101
102
# File 'lib/language_server/protocol/interface/completion_item.rb', line 100

def insert_text
  attributes.fetch(:insertText)
end

#insert_text_formatInsertTextFormat

The format of the insert text. The format applies to both the insertText property and the newText property of a provided textEdit.

Returns:

  • (InsertTextFormat)


109
110
111
# File 'lib/language_server/protocol/interface/completion_item.rb', line 109

def insert_text_format
  attributes.fetch(:insertTextFormat)
end

#kindnumber

The kind of this completion item. Based of the kind an icon is chosen by the editor.

Returns:

  • (number)


41
42
43
# File 'lib/language_server/protocol/interface/completion_item.rb', line 41

def kind
  attributes.fetch(:kind)
end

#labelstring

The label of this completion item. By default also the text that is inserted when selecting this completion.

Returns:

  • (string)


32
33
34
# File 'lib/language_server/protocol/interface/completion_item.rb', line 32

def label
  attributes.fetch(:label)
end

#sort_textstring

A string that should be used when comparing this item with other items. When falsy the label is used.

Returns:

  • (string)


75
76
77
# File 'lib/language_server/protocol/interface/completion_item.rb', line 75

def sort_text
  attributes.fetch(:sortText)
end

#text_editTextEdit

An edit which is applied to a document when selecting this completion. When an edit is provided the value of insertText is ignored.

Note: The range of the edit must be a single line range and it must contain the position at which completion has been requested.

Returns:



121
122
123
# File 'lib/language_server/protocol/interface/completion_item.rb', line 121

def text_edit
  attributes.fetch(:textEdit)
end

#to_hashObject



170
171
172
# File 'lib/language_server/protocol/interface/completion_item.rb', line 170

def to_hash
  attributes
end

#to_json(*args) ⇒ Object



174
175
176
# File 'lib/language_server/protocol/interface/completion_item.rb', line 174

def to_json(*args)
  to_hash.to_json(*args)
end