Class: LanguageServer::Protocol::Interface::CompletionRegistrationOptions

Inherits:
TextDocumentRegistrationOptions show all
Defined in:
lib/language_server/protocol/interface/completion_registration_options.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from TextDocumentRegistrationOptions

#document_selector

Constructor Details

#initialize(document_selector:, trigger_characters: nil, resolve_provider: nil) ⇒ CompletionRegistrationOptions

Returns a new instance of CompletionRegistrationOptions.



5
6
7
8
9
10
11
12
# File 'lib/language_server/protocol/interface/completion_registration_options.rb', line 5

def initialize(document_selector:, trigger_characters: nil, resolve_provider: nil)
  @attributes = {}

  @attributes[:triggerCharacters] = trigger_characters if trigger_characters
  @attributes[:resolveProvider] = resolve_provider if resolve_provider

  @attributes.freeze
end

Instance Attribute Details

#attributesObject (readonly)

Returns the value of attribute attributes.



38
39
40
# File 'lib/language_server/protocol/interface/completion_registration_options.rb', line 38

def attributes
  @attributes
end

Instance Method Details

#resolve_providerboolean

The server provides support to resolve additional information for a completion item.

Returns:

  • (boolean)


34
35
36
# File 'lib/language_server/protocol/interface/completion_registration_options.rb', line 34

def resolve_provider
  attributes.fetch(:resolveProvider)
end

#to_hashObject



40
41
42
# File 'lib/language_server/protocol/interface/completion_registration_options.rb', line 40

def to_hash
  attributes
end

#to_json(*args) ⇒ Object



44
45
46
# File 'lib/language_server/protocol/interface/completion_registration_options.rb', line 44

def to_json(*args)
  to_hash.to_json(*args)
end

#trigger_charactersstring[]

Most tools trigger completion request automatically without explicitly requesting it using a keyboard shortcut (e.g. Ctrl+Space). Typically they do so when the user starts to type an identifier. For example if the user types c in a JavaScript file code complete will automatically pop up present console besides others as a completion item. Characters that make up identifiers don’t need to be listed here.

If code complete should automatically be trigger on characters not being valid inside an identifier (for example . in JavaScript) list them in triggerCharacters.

Returns:

  • (string[])


25
26
27
# File 'lib/language_server/protocol/interface/completion_registration_options.rb', line 25

def trigger_characters
  attributes.fetch(:triggerCharacters)
end