Class: LanguageServer::Protocol::Interface::DiagnosticClientCapabilities
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::DiagnosticClientCapabilities
- Defined in:
- lib/language_server/protocol/interface/diagnostic_client_capabilities.rb
Overview
Client capabilities specific to diagnostic pull requests.
Instance Attribute Summary collapse
- #attributes ⇒ Object readonly
Instance Method Summary collapse
-
#dynamic_registration ⇒ boolean | nil
Whether implementation supports dynamic registration.
-
#initialize(dynamic_registration: nil, related_document_support: nil) ⇒ DiagnosticClientCapabilities
constructor
A new instance of DiagnosticClientCapabilities.
-
#related_document_support ⇒ boolean | nil
Whether the clients supports related documents for document diagnostic pulls.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
Constructor Details
#initialize(dynamic_registration: nil, related_document_support: nil) ⇒ DiagnosticClientCapabilities
Returns a new instance of DiagnosticClientCapabilities.
10 11 12 13 14 15 16 17 |
# File 'lib/language_server/protocol/interface/diagnostic_client_capabilities.rb', line 10 def initialize(dynamic_registration: nil, related_document_support: nil) @attributes = {} @attributes[:dynamicRegistration] = dynamic_registration if dynamic_registration @attributes[:relatedDocumentSupport] = if @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
37 38 39 |
# File 'lib/language_server/protocol/interface/diagnostic_client_capabilities.rb', line 37 def attributes @attributes end |
Instance Method Details
#dynamic_registration ⇒ boolean | nil
Whether implementation supports dynamic registration. If this is set to true the client supports the new ‘(TextDocumentRegistrationOptions & StaticRegistrationOptions)` return value for the corresponding server capability as well.
25 26 27 |
# File 'lib/language_server/protocol/interface/diagnostic_client_capabilities.rb', line 25 def dynamic_registration attributes.fetch(:dynamicRegistration) end |
#related_document_support ⇒ boolean | nil
Whether the clients supports related documents for document diagnostic pulls.
33 34 35 |
# File 'lib/language_server/protocol/interface/diagnostic_client_capabilities.rb', line 33 def attributes.fetch(:relatedDocumentSupport) end |
#to_hash ⇒ Object
39 40 41 |
# File 'lib/language_server/protocol/interface/diagnostic_client_capabilities.rb', line 39 def to_hash attributes end |
#to_json(*args) ⇒ Object
43 44 45 |
# File 'lib/language_server/protocol/interface/diagnostic_client_capabilities.rb', line 43 def to_json(*args) to_hash.to_json(*args) end |