Class: LanguageServer::Protocol::Interface::DidChangeTextDocumentParams
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::DidChangeTextDocumentParams
- Defined in:
- lib/language_server/protocol/interface/did_change_text_document_params.rb
Overview
The change text document notification’s parameters.
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
Instance Method Summary collapse
-
#content_changes ⇒ TextDocumentContentChangeEvent[]
The actual content changes.
-
#initialize(text_document:, content_changes:) ⇒ DidChangeTextDocumentParams
constructor
A new instance of DidChangeTextDocumentParams.
-
#text_document ⇒ VersionedTextDocumentIdentifier
The document that did change.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
Constructor Details
#initialize(text_document:, content_changes:) ⇒ DidChangeTextDocumentParams
8 9 10 11 12 13 14 15 |
# File 'lib/language_server/protocol/interface/did_change_text_document_params.rb', line 8 def initialize(text_document:, content_changes:) @attributes = {} @attributes[:textDocument] = text_document @attributes[:contentChanges] = content_changes @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
45 46 47 |
# File 'lib/language_server/protocol/interface/did_change_text_document_params.rb', line 45 def attributes @attributes end |
Instance Method Details
#content_changes ⇒ TextDocumentContentChangeEvent[]
The actual content changes. The content changes describe single state changes to the document. So if there are two content changes c1 (at array index 0) and c2 (at array index 1) for a document in state S then c1 moves the document from S to S’ and c2 from S’ to S”. So c1 is computed on the state S and c2 is computed on the state S’.
To mirror the content of a document using change events use the following approach:
-
start with the same initial content
-
apply the ‘textDocument/didChange’ notifications in the order you receive them.
-
apply the ‘TextDocumentContentChangeEvent`s in a single notification in the order you receive them.
41 42 43 |
# File 'lib/language_server/protocol/interface/did_change_text_document_params.rb', line 41 def content_changes attributes.fetch(:contentChanges) end |
#text_document ⇒ VersionedTextDocumentIdentifier
The document that did change. The version number points to the version after all provided content changes have been applied.
23 24 25 |
# File 'lib/language_server/protocol/interface/did_change_text_document_params.rb', line 23 def text_document attributes.fetch(:textDocument) end |
#to_hash ⇒ Object
47 48 49 |
# File 'lib/language_server/protocol/interface/did_change_text_document_params.rb', line 47 def to_hash attributes end |
#to_json(*args) ⇒ Object
51 52 53 |
# File 'lib/language_server/protocol/interface/did_change_text_document_params.rb', line 51 def to_json(*args) to_hash.to_json(*args) end |