Class: LanguageServer::Protocol::Interface::DocumentOnTypeFormattingParams
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::DocumentOnTypeFormattingParams
- Defined in:
- lib/language_server/protocol/interface/document_on_type_formatting_params.rb,
sig/language_server/protocol/interface/document_on_type_formatting_params.rbs
Overview
The parameters of a DocumentOnTypeFormattingRequest.
Instance Attribute Summary collapse
-
#attributes ⇒ Hash[Symbol, untyped]
readonly
Returns the value of attribute attributes.
Instance Method Summary collapse
-
#ch ⇒ string
The character that has been typed that triggered the formatting on type request.
-
#initialize(text_document:, position:, ch:, options:) ⇒ DocumentOnTypeFormattingParams
constructor
A new instance of DocumentOnTypeFormattingParams.
-
#options ⇒ FormattingOptions
The formatting options.
-
#position ⇒ Position
The position around which the on type formatting should happen.
-
#text_document ⇒ TextDocumentIdentifier
The document to format.
- #to_hash ⇒ Hash[Symbol, untyped]
- #to_json(*args) ⇒ String
Constructor Details
#initialize(text_document:, position:, ch:, options:) ⇒ DocumentOnTypeFormattingParams
Returns a new instance of DocumentOnTypeFormattingParams.
8 9 10 11 12 13 14 15 16 17 |
# File 'lib/language_server/protocol/interface/document_on_type_formatting_params.rb', line 8 def initialize(text_document:, position:, ch:, options:) @attributes = {} @attributes[:textDocument] = text_document @attributes[:position] = position @attributes[:ch] = ch @attributes[:options] = @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Hash[Symbol, untyped] (readonly)
Returns the value of attribute attributes.
56 57 58 |
# File 'lib/language_server/protocol/interface/document_on_type_formatting_params.rb', line 56 def attributes @attributes end |
Instance Method Details
#ch ⇒ string
The character that has been typed that triggered the formatting on type request. That is not necessarily the last character that got inserted into the document since the client could auto insert characters as well (e.g. like automatic brace completion).
44 45 46 |
# File 'lib/language_server/protocol/interface/document_on_type_formatting_params.rb', line 44 def ch attributes.fetch(:ch) end |
#options ⇒ FormattingOptions
The formatting options.
52 53 54 |
# File 'lib/language_server/protocol/interface/document_on_type_formatting_params.rb', line 52 def attributes.fetch(:options) end |
#position ⇒ Position
The position around which the on type formatting should happen.
This is not necessarily the exact position where the character denoted
by the property ch got typed.
33 34 35 |
# File 'lib/language_server/protocol/interface/document_on_type_formatting_params.rb', line 33 def position attributes.fetch(:position) end |
#text_document ⇒ TextDocumentIdentifier
The document to format.
23 24 25 |
# File 'lib/language_server/protocol/interface/document_on_type_formatting_params.rb', line 23 def text_document attributes.fetch(:textDocument) end |
#to_hash ⇒ Hash[Symbol, untyped]
58 59 60 |
# File 'lib/language_server/protocol/interface/document_on_type_formatting_params.rb', line 58 def to_hash attributes end |
#to_json(*args) ⇒ String
62 63 64 |
# File 'lib/language_server/protocol/interface/document_on_type_formatting_params.rb', line 62 def to_json(*args) to_hash.to_json(*args) end |