Class: LanguageServer::Protocol::Interface::InlayHintLabelPart
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::InlayHintLabelPart
- Defined in:
- lib/language_server/protocol/interface/inlay_hint_label_part.rb
Overview
An inlay hint label part allows for interactive and composite labels of inlay hints.
Instance Attribute Summary collapse
- #attributes ⇒ Object readonly
Instance Method Summary collapse
-
#command ⇒ Command | nil
An optional command for this label part.
-
#initialize(value:, tooltip: nil, location: nil, command: nil) ⇒ InlayHintLabelPart
constructor
A new instance of InlayHintLabelPart.
-
#location ⇒ Location | nil
An optional source code location that represents this label part.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
-
#tooltip ⇒ string | MarkupContent | nil
The tooltip text when you hover over this label part.
-
#value ⇒ string
The value of this label part.
Constructor Details
#initialize(value:, tooltip: nil, location: nil, command: nil) ⇒ InlayHintLabelPart
Returns a new instance of InlayHintLabelPart.
11 12 13 14 15 16 17 18 19 20 |
# File 'lib/language_server/protocol/interface/inlay_hint_label_part.rb', line 11 def initialize(value:, tooltip: nil, location: nil, command: nil) @attributes = {} @attributes[:value] = value @attributes[:tooltip] = tooltip if tooltip @attributes[:location] = location if location @attributes[:command] = command if command @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
69 70 71 |
# File 'lib/language_server/protocol/interface/inlay_hint_label_part.rb', line 69 def attributes @attributes end |
Instance Method Details
#command ⇒ Command | nil
An optional command for this label part.
Depending on the client capability inlayHint.resolveSupport clients might resolve this property late using the resolve request.
65 66 67 |
# File 'lib/language_server/protocol/interface/inlay_hint_label_part.rb', line 65 def command attributes.fetch(:command) end |
#location ⇒ Location | nil
An optional source code location that represents this label part.
The editor will use this location for the hover and for code navigation features: This part will become a clickable link that resolves to the definition of the symbol at the given location (not necessarily the location itself), it shows the hover that shows at the given location, and it shows a context menu with further code navigation commands.
Depending on the client capability inlayHint.resolveSupport clients might resolve this property late using the resolve request.
54 55 56 |
# File 'lib/language_server/protocol/interface/inlay_hint_label_part.rb', line 54 def location attributes.fetch(:location) end |
#to_hash ⇒ Object
71 72 73 |
# File 'lib/language_server/protocol/interface/inlay_hint_label_part.rb', line 71 def to_hash attributes end |
#to_json(*args) ⇒ Object
75 76 77 |
# File 'lib/language_server/protocol/interface/inlay_hint_label_part.rb', line 75 def to_json(*args) to_hash.to_json(*args) end |
#tooltip ⇒ string | MarkupContent | nil
The tooltip text when you hover over this label part. Depending on the client capability inlayHint.resolveSupport clients might resolve this property late using the resolve request.
36 37 38 |
# File 'lib/language_server/protocol/interface/inlay_hint_label_part.rb', line 36 def tooltip attributes.fetch(:tooltip) end |
#value ⇒ string
The value of this label part.
26 27 28 |
# File 'lib/language_server/protocol/interface/inlay_hint_label_part.rb', line 26 def value attributes.fetch(:value) end |