Method: LanguageServer::Protocol::Interface::InlineValueRegistrationOptions#document_selector
- Defined in:
- lib/language_server/protocol/interface/inline_value_registration_options.rb
#document_selector ⇒ DocumentSelector
A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.
28 29 30 |
# File 'lib/language_server/protocol/interface/inline_value_registration_options.rb', line 28 def document_selector attributes.fetch(:documentSelector) end |