Class: LanguageServer::Protocol::Interface::LinkedEditingRanges

Inherits:
Object
  • Object
show all
Defined in:
lib/language_server/protocol/interface/linked_editing_ranges.rb

Overview

The result of a linked editing range request.

Since:

  • 3.16.0

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ranges:, word_pattern: nil) ⇒ LinkedEditingRanges

Returns a new instance of LinkedEditingRanges.

Since:

  • 3.16.0



10
11
12
13
14
15
16
17
# File 'lib/language_server/protocol/interface/linked_editing_ranges.rb', line 10

def initialize(ranges:, word_pattern: nil)
  @attributes = {}

  @attributes[:ranges] = ranges
  @attributes[:wordPattern] = word_pattern if word_pattern

  @attributes.freeze
end

Instance Attribute Details

#attributesObject (readonly)

Since:

  • 3.16.0



38
39
40
# File 'lib/language_server/protocol/interface/linked_editing_ranges.rb', line 38

def attributes
  @attributes
end

Instance Method Details

#rangesRange[]

A list of ranges that can be edited together. The ranges must have identical length and contain identical text content. The ranges cannot overlap.

Returns:

Since:

  • 3.16.0



24
25
26
# File 'lib/language_server/protocol/interface/linked_editing_ranges.rb', line 24

def ranges
  attributes.fetch(:ranges)
end

#to_hashObject

Since:

  • 3.16.0



40
41
42
# File 'lib/language_server/protocol/interface/linked_editing_ranges.rb', line 40

def to_hash
  attributes
end

#to_json(*args) ⇒ Object

Since:

  • 3.16.0



44
45
46
# File 'lib/language_server/protocol/interface/linked_editing_ranges.rb', line 44

def to_json(*args)
  to_hash.to_json(*args)
end

#word_patternstring | nil

An optional word pattern (regular expression) that describes valid contents for the given ranges. If no pattern is provided, the client configuration’s word pattern will be used.

Returns:

  • (string | nil)

Since:

  • 3.16.0



34
35
36
# File 'lib/language_server/protocol/interface/linked_editing_ranges.rb', line 34

def word_pattern
  attributes.fetch(:wordPattern)
end