Class: LanguageServer::Protocol::Interface::LinkedEditingRanges
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::LinkedEditingRanges
- Defined in:
- lib/language_server/protocol/interface/linked_editing_ranges.rb
Overview
The result of a linked editing range request.
Instance Attribute Summary collapse
- #attributes ⇒ Object readonly
Instance Method Summary collapse
-
#initialize(ranges:, word_pattern: nil) ⇒ LinkedEditingRanges
constructor
A new instance of LinkedEditingRanges.
-
#ranges ⇒ Range[]
A list of ranges that can be edited together.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
-
#word_pattern ⇒ string | nil
An optional word pattern (regular expression) that describes valid contents for the given ranges.
Constructor Details
#initialize(ranges:, word_pattern: nil) ⇒ LinkedEditingRanges
Returns a new instance of LinkedEditingRanges.
10 11 12 13 14 15 16 17 |
# File 'lib/language_server/protocol/interface/linked_editing_ranges.rb', line 10 def initialize(ranges:, word_pattern: nil) @attributes = {} @attributes[:ranges] = ranges @attributes[:wordPattern] = word_pattern if word_pattern @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
38 39 40 |
# File 'lib/language_server/protocol/interface/linked_editing_ranges.rb', line 38 def attributes @attributes end |
Instance Method Details
#ranges ⇒ Range[]
A list of ranges that can be edited together. The ranges must have identical length and contain identical text content. The ranges cannot overlap.
24 25 26 |
# File 'lib/language_server/protocol/interface/linked_editing_ranges.rb', line 24 def ranges attributes.fetch(:ranges) end |
#to_hash ⇒ Object
40 41 42 |
# File 'lib/language_server/protocol/interface/linked_editing_ranges.rb', line 40 def to_hash attributes end |
#to_json(*args) ⇒ Object
44 45 46 |
# File 'lib/language_server/protocol/interface/linked_editing_ranges.rb', line 44 def to_json(*args) to_hash.to_json(*args) end |
#word_pattern ⇒ string | nil
An optional word pattern (regular expression) that describes valid contents for the given ranges. If no pattern is provided, the client configuration’s word pattern will be used.
34 35 36 |
# File 'lib/language_server/protocol/interface/linked_editing_ranges.rb', line 34 def word_pattern attributes.fetch(:wordPattern) end |