Class: LanguageServer::Protocol::Interface::NotebookDocumentSyncClientCapabilities
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::NotebookDocumentSyncClientCapabilities
- Defined in:
- lib/language_server/protocol/interface/notebook_document_sync_client_capabilities.rb
Overview
Notebook specific client capabilities.
Instance Attribute Summary collapse
- #attributes ⇒ Object readonly
Instance Method Summary collapse
-
#dynamic_registration ⇒ boolean | nil
Whether implementation supports dynamic registration.
-
#execution_summary_support ⇒ boolean | nil
The client supports sending execution summary data per cell.
-
#initialize(dynamic_registration: nil, execution_summary_support: nil) ⇒ NotebookDocumentSyncClientCapabilities
constructor
A new instance of NotebookDocumentSyncClientCapabilities.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
Constructor Details
#initialize(dynamic_registration: nil, execution_summary_support: nil) ⇒ NotebookDocumentSyncClientCapabilities
Returns a new instance of NotebookDocumentSyncClientCapabilities.
10 11 12 13 14 15 16 17 |
# File 'lib/language_server/protocol/interface/notebook_document_sync_client_capabilities.rb', line 10 def initialize(dynamic_registration: nil, execution_summary_support: nil) @attributes = {} @attributes[:dynamicRegistration] = dynamic_registration if dynamic_registration @attributes[:executionSummarySupport] = execution_summary_support if execution_summary_support @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
38 39 40 |
# File 'lib/language_server/protocol/interface/notebook_document_sync_client_capabilities.rb', line 38 def attributes @attributes end |
Instance Method Details
#dynamic_registration ⇒ boolean | nil
Whether implementation supports dynamic registration. If this is set to true the client supports the new ‘(TextDocumentRegistrationOptions & StaticRegistrationOptions)` return value for the corresponding server capability as well.
26 27 28 |
# File 'lib/language_server/protocol/interface/notebook_document_sync_client_capabilities.rb', line 26 def dynamic_registration attributes.fetch(:dynamicRegistration) end |
#execution_summary_support ⇒ boolean | nil
The client supports sending execution summary data per cell.
34 35 36 |
# File 'lib/language_server/protocol/interface/notebook_document_sync_client_capabilities.rb', line 34 def execution_summary_support attributes.fetch(:executionSummarySupport) end |
#to_hash ⇒ Object
40 41 42 |
# File 'lib/language_server/protocol/interface/notebook_document_sync_client_capabilities.rb', line 40 def to_hash attributes end |
#to_json(*args) ⇒ Object
44 45 46 |
# File 'lib/language_server/protocol/interface/notebook_document_sync_client_capabilities.rb', line 44 def to_json(*args) to_hash.to_json(*args) end |