Class: LanguageServer::Protocol::Interface::NotebookDocumentSyncRegistrationOptions
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::NotebookDocumentSyncRegistrationOptions
- Defined in:
- lib/language_server/protocol/interface/notebook_document_sync_registration_options.rb
Overview
Registration options specific to a notebook.
Instance Attribute Summary collapse
- #attributes ⇒ Object readonly
Instance Method Summary collapse
-
#id ⇒ string | nil
The id used to register the request.
-
#initialize(notebook_selector:, save: nil, id: nil) ⇒ NotebookDocumentSyncRegistrationOptions
constructor
A new instance of NotebookDocumentSyncRegistrationOptions.
-
#notebook_selector ⇒ { notebook:string | NotebookDocumentFilter, cells:{ language:string }[] } | { notebook:string | NotebookDocumentFilter, cells:{ language:string }[] }[]
The notebooks to be synced.
-
#save ⇒ boolean | nil
Whether save notification should be forwarded to the server.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
Constructor Details
#initialize(notebook_selector:, save: nil, id: nil) ⇒ NotebookDocumentSyncRegistrationOptions
Returns a new instance of NotebookDocumentSyncRegistrationOptions.
10 11 12 13 14 15 16 17 18 |
# File 'lib/language_server/protocol/interface/notebook_document_sync_registration_options.rb', line 10 def initialize(notebook_selector:, save: nil, id: nil) @attributes = {} @attributes[:notebookSelector] = notebook_selector @attributes[:save] = save if save @attributes[:id] = id if id @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
46 47 48 |
# File 'lib/language_server/protocol/interface/notebook_document_sync_registration_options.rb', line 46 def attributes @attributes end |
Instance Method Details
#id ⇒ string | nil
The id used to register the request. The id can be used to deregister the request again. See also Registration#id.
42 43 44 |
# File 'lib/language_server/protocol/interface/notebook_document_sync_registration_options.rb', line 42 def id attributes.fetch(:id) end |
#notebook_selector ⇒ { notebook:string | NotebookDocumentFilter, cells:{ language:string }[] } | { notebook:string | NotebookDocumentFilter, cells:{ language:string }[] }[]
The notebooks to be synced
24 25 26 |
# File 'lib/language_server/protocol/interface/notebook_document_sync_registration_options.rb', line 24 def notebook_selector attributes.fetch(:notebookSelector) end |
#save ⇒ boolean | nil
Whether save notification should be forwarded to the server. Will only be honored if mode === notebook.
33 34 35 |
# File 'lib/language_server/protocol/interface/notebook_document_sync_registration_options.rb', line 33 def save attributes.fetch(:save) end |
#to_hash ⇒ Object
48 49 50 |
# File 'lib/language_server/protocol/interface/notebook_document_sync_registration_options.rb', line 48 def to_hash attributes end |
#to_json(*args) ⇒ Object
52 53 54 |
# File 'lib/language_server/protocol/interface/notebook_document_sync_registration_options.rb', line 52 def to_json(*args) to_hash.to_json(*args) end |