Class: LanguageServer::Protocol::Interface::OptionalVersionedTextDocumentIdentifier
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::OptionalVersionedTextDocumentIdentifier
- Defined in:
- lib/language_server/protocol/interface/optional_versioned_text_document_identifier.rb
Overview
A text document identifier to optionally denote a specific version of a text document.
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
Instance Method Summary collapse
-
#initialize(version:, uri:) ⇒ OptionalVersionedTextDocumentIdentifier
constructor
A new instance of OptionalVersionedTextDocumentIdentifier.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
-
#uri ⇒ DocumentUri
The text document’s uri.
-
#version ⇒ integer | null
The version number of this document.
Constructor Details
#initialize(version:, uri:) ⇒ OptionalVersionedTextDocumentIdentifier
Returns a new instance of OptionalVersionedTextDocumentIdentifier.
8 9 10 11 12 13 14 15 |
# File 'lib/language_server/protocol/interface/optional_versioned_text_document_identifier.rb', line 8 def initialize(version:, uri:) @attributes = {} @attributes[:version] = version @attributes[:uri] = uri @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
37 38 39 |
# File 'lib/language_server/protocol/interface/optional_versioned_text_document_identifier.rb', line 37 def attributes @attributes end |
Instance Method Details
#to_hash ⇒ Object
39 40 41 |
# File 'lib/language_server/protocol/interface/optional_versioned_text_document_identifier.rb', line 39 def to_hash attributes end |
#to_json(*args) ⇒ Object
43 44 45 |
# File 'lib/language_server/protocol/interface/optional_versioned_text_document_identifier.rb', line 43 def to_json(*args) to_hash.to_json(*args) end |
#uri ⇒ DocumentUri
The text document’s uri.
33 34 35 |
# File 'lib/language_server/protocol/interface/optional_versioned_text_document_identifier.rb', line 33 def uri attributes.fetch(:uri) end |
#version ⇒ integer | null
The version number of this document. If a versioned text document identifier is sent from the server to the client and the file is not open in the editor (the server has not received an open notification before) the server can send null to indicate that the version is unknown and the content on disk is the truth (as specified with document content ownership).
25 26 27 |
# File 'lib/language_server/protocol/interface/optional_versioned_text_document_identifier.rb', line 25 def version attributes.fetch(:version) end |