Class: LanguageServer::Protocol::Interface::PreviousResultId
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::PreviousResultId
- Defined in:
- lib/language_server/protocol/interface/previous_result_id.rb
Overview
A previous result id in a workspace pull request.
Instance Attribute Summary collapse
- #attributes ⇒ Object readonly
Instance Method Summary collapse
-
#initialize(uri:, value:) ⇒ PreviousResultId
constructor
A new instance of PreviousResultId.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
-
#uri ⇒ DocumentUri
The URI for which the client knows a result id.
-
#value ⇒ string
The value of the previous result id.
Constructor Details
#initialize(uri:, value:) ⇒ PreviousResultId
Returns a new instance of PreviousResultId.
10 11 12 13 14 15 16 17 |
# File 'lib/language_server/protocol/interface/previous_result_id.rb', line 10 def initialize(uri:, value:) @attributes = {} @attributes[:uri] = uri @attributes[:value] = value @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
36 37 38 |
# File 'lib/language_server/protocol/interface/previous_result_id.rb', line 36 def attributes @attributes end |
Instance Method Details
#to_hash ⇒ Object
38 39 40 |
# File 'lib/language_server/protocol/interface/previous_result_id.rb', line 38 def to_hash attributes end |
#to_json(*args) ⇒ Object
42 43 44 |
# File 'lib/language_server/protocol/interface/previous_result_id.rb', line 42 def to_json(*args) to_hash.to_json(*args) end |
#uri ⇒ DocumentUri
The URI for which the client knows a result id.
24 25 26 |
# File 'lib/language_server/protocol/interface/previous_result_id.rb', line 24 def uri attributes.fetch(:uri) end |
#value ⇒ string
The value of the previous result id.
32 33 34 |
# File 'lib/language_server/protocol/interface/previous_result_id.rb', line 32 def value attributes.fetch(:value) end |