Class: LanguageServer::Protocol::Interface::RelatedUnchangedDocumentDiagnosticReport
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::RelatedUnchangedDocumentDiagnosticReport
- Defined in:
- lib/language_server/protocol/interface/related_unchanged_document_diagnostic_report.rb
Overview
An unchanged diagnostic report with a set of related documents.
Instance Attribute Summary collapse
- #attributes ⇒ Object readonly
Instance Method Summary collapse
-
#initialize(related_documents: nil, kind:, result_id:) ⇒ RelatedUnchangedDocumentDiagnosticReport
constructor
A new instance of RelatedUnchangedDocumentDiagnosticReport.
-
#kind ⇒ "unchanged"
A document diagnostic report indicating no changes to the last result.
-
#related_documents ⇒ DocumentUri => FullDocumentDiagnosticReport | UnchangedDocumentDiagnosticReport | nil
Diagnostics of related documents.
-
#result_id ⇒ string
A result id which will be sent on the next diagnostic request for the same document.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
Constructor Details
#initialize(related_documents: nil, kind:, result_id:) ⇒ RelatedUnchangedDocumentDiagnosticReport
Returns a new instance of RelatedUnchangedDocumentDiagnosticReport.
10 11 12 13 14 15 16 17 18 |
# File 'lib/language_server/protocol/interface/related_unchanged_document_diagnostic_report.rb', line 10 def initialize(related_documents: nil, kind:, result_id:) @attributes = {} @attributes[:relatedDocuments] = if @attributes[:kind] = kind @attributes[:resultId] = result_id @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
54 55 56 |
# File 'lib/language_server/protocol/interface/related_unchanged_document_diagnostic_report.rb', line 54 def attributes @attributes end |
Instance Method Details
#kind ⇒ "unchanged"
A document diagnostic report indicating no changes to the last result. A server can only return unchanged if result ids are provided.
41 42 43 |
# File 'lib/language_server/protocol/interface/related_unchanged_document_diagnostic_report.rb', line 41 def kind attributes.fetch(:kind) end |
#related_documents ⇒ DocumentUri => FullDocumentDiagnosticReport | UnchangedDocumentDiagnosticReport | nil
Diagnostics of related documents. This information is useful in programming languages where code in a file A can generate diagnostics in a file B which A depends on. An example of such a language is C/C++ where marco definitions in a file a.cpp and result in errors in a header file b.hpp.
30 31 32 |
# File 'lib/language_server/protocol/interface/related_unchanged_document_diagnostic_report.rb', line 30 def attributes.fetch(:relatedDocuments) end |
#result_id ⇒ string
A result id which will be sent on the next diagnostic request for the same document.
50 51 52 |
# File 'lib/language_server/protocol/interface/related_unchanged_document_diagnostic_report.rb', line 50 def result_id attributes.fetch(:resultId) end |
#to_hash ⇒ Object
56 57 58 |
# File 'lib/language_server/protocol/interface/related_unchanged_document_diagnostic_report.rb', line 56 def to_hash attributes end |
#to_json(*args) ⇒ Object
60 61 62 |
# File 'lib/language_server/protocol/interface/related_unchanged_document_diagnostic_report.rb', line 60 def to_json(*args) to_hash.to_json(*args) end |