Class: LanguageServer::Protocol::Interface::SelectionRangeClientCapabilities
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::SelectionRangeClientCapabilities
- Defined in:
- lib/language_server/protocol/interface/selection_range_client_capabilities.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
Instance Method Summary collapse
-
#dynamic_registration ⇒ boolean | nil
Whether implementation supports dynamic registration for selection range providers.
-
#initialize(dynamic_registration: nil) ⇒ SelectionRangeClientCapabilities
constructor
A new instance of SelectionRangeClientCapabilities.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
Constructor Details
#initialize(dynamic_registration: nil) ⇒ SelectionRangeClientCapabilities
Returns a new instance of SelectionRangeClientCapabilities.
5 6 7 8 9 10 11 |
# File 'lib/language_server/protocol/interface/selection_range_client_capabilities.rb', line 5 def initialize(dynamic_registration: nil) @attributes = {} @attributes[:dynamicRegistration] = dynamic_registration if dynamic_registration @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
23 24 25 |
# File 'lib/language_server/protocol/interface/selection_range_client_capabilities.rb', line 23 def attributes @attributes end |
Instance Method Details
#dynamic_registration ⇒ boolean | nil
Whether implementation supports dynamic registration for selection range providers. If this is set to true the client supports the new SelectionRangeRegistrationOptions return value for the corresponding server capability as well.
19 20 21 |
# File 'lib/language_server/protocol/interface/selection_range_client_capabilities.rb', line 19 def dynamic_registration attributes.fetch(:dynamicRegistration) end |
#to_hash ⇒ Object
25 26 27 |
# File 'lib/language_server/protocol/interface/selection_range_client_capabilities.rb', line 25 def to_hash attributes end |
#to_json(*args) ⇒ Object
29 30 31 |
# File 'lib/language_server/protocol/interface/selection_range_client_capabilities.rb', line 29 def to_json(*args) to_hash.to_json(*args) end |