Class: LanguageServer::Protocol::Interface::SelectionRangeClientCapabilities
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::SelectionRangeClientCapabilities
- Defined in:
- lib/language_server/protocol/interface/selection_range_client_capabilities.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
Instance Method Summary collapse
-
#dynamic_registration ⇒ boolean
Whether implementation supports dynamic registration for selection range providers.
-
#initialize(dynamic_registration: nil) ⇒ SelectionRangeClientCapabilities
constructor
A new instance of SelectionRangeClientCapabilities.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
Constructor Details
#initialize(dynamic_registration: nil) ⇒ SelectionRangeClientCapabilities
Returns a new instance of SelectionRangeClientCapabilities.
5 6 7 8 9 10 11 |
# File 'lib/language_server/protocol/interface/selection_range_client_capabilities.rb', line 5 def initialize(dynamic_registration: nil) @attributes = {} @attributes[:dynamicRegistration] = dynamic_registration if dynamic_registration @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
24 25 26 |
# File 'lib/language_server/protocol/interface/selection_range_client_capabilities.rb', line 24 def attributes @attributes end |
Instance Method Details
#dynamic_registration ⇒ boolean
Whether implementation supports dynamic registration for selection range providers. If this is set to true the client supports the new SelectionRangeRegistrationOptions return value for the corresponding server capability as well.
20 21 22 |
# File 'lib/language_server/protocol/interface/selection_range_client_capabilities.rb', line 20 def dynamic_registration attributes.fetch(:dynamicRegistration) end |
#to_hash ⇒ Object
26 27 28 |
# File 'lib/language_server/protocol/interface/selection_range_client_capabilities.rb', line 26 def to_hash attributes end |
#to_json(*args) ⇒ Object
30 31 32 |
# File 'lib/language_server/protocol/interface/selection_range_client_capabilities.rb', line 30 def to_json(*args) to_hash.to_json(*args) end |