Class: LanguageServer::Protocol::Interface::SemanticTokensDeltaParams
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::SemanticTokensDeltaParams
- Defined in:
- lib/language_server/protocol/interface/semantic_tokens_delta_params.rb
Overview
Instance Attribute Summary collapse
- #attributes ⇒ Object readonly
Instance Method Summary collapse
-
#initialize(text_document:, previous_result_id:, work_done_token: nil, partial_result_token: nil) ⇒ SemanticTokensDeltaParams
constructor
A new instance of SemanticTokensDeltaParams.
-
#partial_result_token ⇒ ProgressToken | nil
An optional token that a server can use to report partial results (e.g. streaming) to the client.
-
#previous_result_id ⇒ string
The result id of a previous response.
-
#text_document ⇒ TextDocumentIdentifier
The text document.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
-
#work_done_token ⇒ ProgressToken | nil
An optional token that a server can use to report work done progress.
Constructor Details
#initialize(text_document:, previous_result_id:, work_done_token: nil, partial_result_token: nil) ⇒ SemanticTokensDeltaParams
Returns a new instance of SemanticTokensDeltaParams.
8 9 10 11 12 13 14 15 16 17 |
# File 'lib/language_server/protocol/interface/semantic_tokens_delta_params.rb', line 8 def initialize(text_document:, previous_result_id:, work_done_token: nil, partial_result_token: nil) @attributes = {} @attributes[:textDocument] = text_document @attributes[:previousResultId] = previous_result_id @attributes[:workDoneToken] = work_done_token if work_done_token @attributes[:partialResultToken] = partial_result_token if partial_result_token @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
53 54 55 |
# File 'lib/language_server/protocol/interface/semantic_tokens_delta_params.rb', line 53 def attributes @attributes end |
Instance Method Details
#partial_result_token ⇒ ProgressToken | nil
An optional token that a server can use to report partial results (e.g. streaming) to the client.
49 50 51 |
# File 'lib/language_server/protocol/interface/semantic_tokens_delta_params.rb', line 49 def partial_result_token attributes.fetch(:partialResultToken) end |
#previous_result_id ⇒ string
The result id of a previous response. The result Id can either point to a full response or a delta response depending on what was received last.
32 33 34 |
# File 'lib/language_server/protocol/interface/semantic_tokens_delta_params.rb', line 32 def previous_result_id attributes.fetch(:previousResultId) end |
#text_document ⇒ TextDocumentIdentifier
The text document.
23 24 25 |
# File 'lib/language_server/protocol/interface/semantic_tokens_delta_params.rb', line 23 def text_document attributes.fetch(:textDocument) end |
#to_hash ⇒ Object
55 56 57 |
# File 'lib/language_server/protocol/interface/semantic_tokens_delta_params.rb', line 55 def to_hash attributes end |
#to_json(*args) ⇒ Object
59 60 61 |
# File 'lib/language_server/protocol/interface/semantic_tokens_delta_params.rb', line 59 def to_json(*args) to_hash.to_json(*args) end |
#work_done_token ⇒ ProgressToken | nil
An optional token that a server can use to report work done progress.
40 41 42 |
# File 'lib/language_server/protocol/interface/semantic_tokens_delta_params.rb', line 40 def work_done_token attributes.fetch(:workDoneToken) end |