Class: LanguageServer::Protocol::Interface::SemanticTokensWorkspaceClientCapabilities
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::SemanticTokensWorkspaceClientCapabilities
- Defined in:
- lib/language_server/protocol/interface/semantic_tokens_workspace_client_capabilities.rb
Overview
Instance Attribute Summary collapse
- #attributes ⇒ Object readonly
Instance Method Summary collapse
-
#initialize(refresh_support: nil) ⇒ SemanticTokensWorkspaceClientCapabilities
constructor
A new instance of SemanticTokensWorkspaceClientCapabilities.
-
#refresh_support ⇒ boolean | nil
Whether the client implementation supports a refresh request sent from the server to the client.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
Constructor Details
#initialize(refresh_support: nil) ⇒ SemanticTokensWorkspaceClientCapabilities
Returns a new instance of SemanticTokensWorkspaceClientCapabilities.
8 9 10 11 12 13 14 |
# File 'lib/language_server/protocol/interface/semantic_tokens_workspace_client_capabilities.rb', line 8 def initialize(refresh_support: nil) @attributes = {} @attributes[:refreshSupport] = refresh_support if refresh_support @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
30 31 32 |
# File 'lib/language_server/protocol/interface/semantic_tokens_workspace_client_capabilities.rb', line 30 def attributes @attributes end |
Instance Method Details
#refresh_support ⇒ boolean | nil
Whether the client implementation supports a refresh request sent from the server to the client.
Note that this event is global and will force the client to refresh all semantic tokens currently shown. It should be used with absolute care and is useful for situation where a server for example detects a project wide change that requires such a calculation.
26 27 28 |
# File 'lib/language_server/protocol/interface/semantic_tokens_workspace_client_capabilities.rb', line 26 def refresh_support attributes.fetch(:refreshSupport) end |
#to_hash ⇒ Object
32 33 34 |
# File 'lib/language_server/protocol/interface/semantic_tokens_workspace_client_capabilities.rb', line 32 def to_hash attributes end |
#to_json(*args) ⇒ Object
36 37 38 |
# File 'lib/language_server/protocol/interface/semantic_tokens_workspace_client_capabilities.rb', line 36 def to_json(*args) to_hash.to_json(*args) end |