Class: LanguageServer::Protocol::Interface::TextDocumentChangeRegistrationOptions
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::TextDocumentChangeRegistrationOptions
- Defined in:
- lib/language_server/protocol/interface/text_document_change_registration_options.rb
Overview
Describe options to be used when registered for text document change events.
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
Instance Method Summary collapse
-
#document_selector ⇒ DocumentSelector | null
A document selector to identify the scope of the registration.
-
#initialize(sync_kind:, document_selector:) ⇒ TextDocumentChangeRegistrationOptions
constructor
A new instance of TextDocumentChangeRegistrationOptions.
-
#sync_kind ⇒ TextDocumentSyncKind
How documents are synced to the server.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
Constructor Details
#initialize(sync_kind:, document_selector:) ⇒ TextDocumentChangeRegistrationOptions
Returns a new instance of TextDocumentChangeRegistrationOptions.
8 9 10 11 12 13 14 15 |
# File 'lib/language_server/protocol/interface/text_document_change_registration_options.rb', line 8 def initialize(sync_kind:, document_selector:) @attributes = {} @attributes[:syncKind] = sync_kind @attributes[:documentSelector] = document_selector @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
34 35 36 |
# File 'lib/language_server/protocol/interface/text_document_change_registration_options.rb', line 34 def attributes @attributes end |
Instance Method Details
#document_selector ⇒ DocumentSelector | null
A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.
30 31 32 |
# File 'lib/language_server/protocol/interface/text_document_change_registration_options.rb', line 30 def document_selector attributes.fetch(:documentSelector) end |
#sync_kind ⇒ TextDocumentSyncKind
How documents are synced to the server.
21 22 23 |
# File 'lib/language_server/protocol/interface/text_document_change_registration_options.rb', line 21 def sync_kind attributes.fetch(:syncKind) end |
#to_hash ⇒ Object
36 37 38 |
# File 'lib/language_server/protocol/interface/text_document_change_registration_options.rb', line 36 def to_hash attributes end |
#to_json(*args) ⇒ Object
40 41 42 |
# File 'lib/language_server/protocol/interface/text_document_change_registration_options.rb', line 40 def to_json(*args) to_hash.to_json(*args) end |