Class: LanguageServer::Protocol::Interface::TextDocumentSaveRegistrationOptions

Inherits:
Object
  • Object
show all
Defined in:
lib/language_server/protocol/interface/text_document_save_registration_options.rb

Overview

Save registration options.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(document_selector:, include_text: nil) ⇒ TextDocumentSaveRegistrationOptions

Returns a new instance of TextDocumentSaveRegistrationOptions.



8
9
10
11
12
13
14
15
# File 'lib/language_server/protocol/interface/text_document_save_registration_options.rb', line 8

def initialize(document_selector:, include_text: nil)
  @attributes = {}

  @attributes[:documentSelector] = document_selector
  @attributes[:includeText] = include_text if include_text

  @attributes.freeze
end

Instance Attribute Details

#attributesObject (readonly)

Returns the value of attribute attributes.



34
35
36
# File 'lib/language_server/protocol/interface/text_document_save_registration_options.rb', line 34

def attributes
  @attributes
end

Instance Method Details

#document_selectorDocumentSelector | null

A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.

Returns:

  • (DocumentSelector | null)


22
23
24
# File 'lib/language_server/protocol/interface/text_document_save_registration_options.rb', line 22

def document_selector
  attributes.fetch(:documentSelector)
end

#include_textboolean | nil

The client is supposed to include the content on save.

Returns:

  • (boolean | nil)


30
31
32
# File 'lib/language_server/protocol/interface/text_document_save_registration_options.rb', line 30

def include_text
  attributes.fetch(:includeText)
end

#to_hashObject



36
37
38
# File 'lib/language_server/protocol/interface/text_document_save_registration_options.rb', line 36

def to_hash
  attributes
end

#to_json(*args) ⇒ Object



40
41
42
# File 'lib/language_server/protocol/interface/text_document_save_registration_options.rb', line 40

def to_json(*args)
  to_hash.to_json(*args)
end