Class: LanguageServer::Protocol::Interface::WindowClientCapabilities
- Inherits:
-
Object
- Object
- LanguageServer::Protocol::Interface::WindowClientCapabilities
- Defined in:
- lib/language_server/protocol/interface/window_client_capabilities.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
Instance Method Summary collapse
-
#initialize(work_done_progress: nil, show_message: nil, show_document: nil) ⇒ WindowClientCapabilities
constructor
A new instance of WindowClientCapabilities.
-
#show_document ⇒ ShowDocumentClientCapabilities | nil
Capabilities specific to the showDocument request.
-
#show_message ⇒ ShowMessageRequestClientCapabilities | nil
Capabilities specific to the showMessage request.
- #to_hash ⇒ Object
- #to_json(*args) ⇒ Object
-
#work_done_progress ⇒ boolean | nil
It indicates whether the client supports server initiated progress using the
window/workDoneProgress/createrequest.
Constructor Details
#initialize(work_done_progress: nil, show_message: nil, show_document: nil) ⇒ WindowClientCapabilities
5 6 7 8 9 10 11 12 13 |
# File 'lib/language_server/protocol/interface/window_client_capabilities.rb', line 5 def initialize(work_done_progress: nil, show_message: nil, show_document: nil) @attributes = {} @attributes[:workDoneProgress] = work_done_progress if work_done_progress @attributes[:showMessage] = if @attributes[:showDocument] = show_document if show_document @attributes.freeze end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
51 52 53 |
# File 'lib/language_server/protocol/interface/window_client_capabilities.rb', line 51 def attributes @attributes end |
Instance Method Details
#show_document ⇒ ShowDocumentClientCapabilities | nil
Capabilities specific to the showDocument request.
47 48 49 |
# File 'lib/language_server/protocol/interface/window_client_capabilities.rb', line 47 def show_document attributes.fetch(:showDocument) end |
#show_message ⇒ ShowMessageRequestClientCapabilities | nil
Capabilities specific to the showMessage request.
37 38 39 |
# File 'lib/language_server/protocol/interface/window_client_capabilities.rb', line 37 def attributes.fetch(:showMessage) end |
#to_hash ⇒ Object
53 54 55 |
# File 'lib/language_server/protocol/interface/window_client_capabilities.rb', line 53 def to_hash attributes end |
#to_json(*args) ⇒ Object
57 58 59 |
# File 'lib/language_server/protocol/interface/window_client_capabilities.rb', line 57 def to_json(*args) to_hash.to_json(*args) end |
#work_done_progress ⇒ boolean | nil
It indicates whether the client supports server initiated progress using the window/workDoneProgress/create request.
The capability also controls Whether client supports handling of progress notifications. If set servers are allowed to report a workDoneProgress property in the request specific server capabilities.
27 28 29 |
# File 'lib/language_server/protocol/interface/window_client_capabilities.rb', line 27 def work_done_progress attributes.fetch(:workDoneProgress) end |